searchData={"items":[{"type":"module","title":"Graph","doc":"This module defines a graph data structure, which supports directed and undirected graphs, in both acyclic and cyclic forms.\nIt also defines the API for creating, manipulating, and querying that structure.\n\nAs far as memory usage is concerned, `Graph` should be fairly compact in memory, but if you want to do a rough\ncomparison between the memory usage for a graph between `libgraph` and `digraph`, use `:digraph.info/1` and\n`Graph.info/1` on the two graphs, and both results will contain memory usage information. Keep in mind we don't have a precise\nway to measure the memory usage of a term in memory, whereas ETS is able to give a more precise answer, but we do have\na fairly good way to estimate the usage of a term, and we use that method within `libgraph`.\n\nThe Graph struct is structured like so:\n\n- A map of vertex ids to vertices (`vertices`)\n- A map of vertex ids to their out neighbors (`out_edges`),\n- A map of vertex ids to their in neighbors (`in_edges`), effectively the transposition of `out_edges`\n- A map of vertex ids to vertex labels (`vertex_labels`), (labels are only stored if a non-nil label was provided)\n- A map of edge ids (where an edge id is simply a tuple of `{vertex_id, vertex_id}`) to a map of edge metadata (`edges`)\n- Edge metadata is a map of `label => weight`, and each entry in that map represents a distinct edge. This allows\n  us to support multiple edges in the same direction between the same pair of vertices, but for many purposes simply\n  treat them as a single logical edge.\n\nThis structure is designed to be as efficient as possible once a graph is built, but it turned out that it is also\nquite efficient for manipulating the graph as well. For example, splitting an edge and introducing a new vertex on that\nedge can be done with very little effort. We use vertex ids everywhere because we can generate them without any lookups,\nwe don't incur any copies of the vertex structure, and they are very efficient as keys in a map.","ref":"Graph.html"},{"type":"function","title":"Graph.a_star/4","doc":"Gets the shortest path between `a` and `b`.\n\nThe A* algorithm is very much like Dijkstra's algorithm, except in addition to edge weights, A*\nalso considers a heuristic function for determining the lower bound of the cost to go from vertex\n`v` to `b`. The lower bound *must* be less than the cost of the shortest path from `v` to `b`, otherwise\nit will do more harm than good. Dijkstra's algorithm can be reframed as A* where `lower_bound(v)` is always 0.\n\nThis function puts the heuristics in your hands, so you must provide the heuristic function, which should take\na single parameter, `v`, which is the vertex being currently examined. Your heuristic should then determine what the\nlower bound for the cost to reach `b` from `v` is, and return that value.","ref":"Graph.html#a_star/4"},{"type":"function","title":"Example - Graph.a_star/4","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :c}, {:c, :d}, {:b, :d}])\n    ...> Graph.a_star(g, :a, :d, fn _ -> 0 end)\n    [:a, :b, :d]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :c}, {:b, :c}, {:b, :d}])\n    ...> Graph.a_star(g, :a, :d, fn _ -> 0 end)\n    nil","ref":"Graph.html#a_star/4-example"},{"type":"function","title":"Graph.add_edge/2","doc":"Like `add_edge/3` or `add_edge/4`, but takes a `Graph.Edge` struct created with\n`Graph.Edge.new/2` or `Graph.Edge.new/3`.","ref":"Graph.html#add_edge/2"},{"type":"function","title":"Example - Graph.add_edge/2","doc":"iex> g = Graph.new |> Graph.add_edge(Graph.Edge.new(:a, :b))\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b}]","ref":"Graph.html#add_edge/2-example"},{"type":"function","title":"Graph.add_edge/4","doc":"Adds an edge connecting `v1` to `v2`. If either `v1` or `v2` do not exist in the graph,\nthey are automatically added. Adding the same edge more than once does not create multiple edges,\neach edge is only ever stored once.\n\nEdges have a default weight of 1, and an empty (nil) label. You can change this by passing options\nto this function, as shown below.","ref":"Graph.html#add_edge/4"},{"type":"function","title":"Example - Graph.add_edge/4","doc":"iex> g = Graph.new |> Graph.add_edge(:a, :b)\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: nil, weight: 1}]\n\n    iex> g = Graph.new |> Graph.add_edge(:a, :b, label: :foo, weight: 2)\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo, weight: 2}]","ref":"Graph.html#add_edge/4-example"},{"type":"function","title":"Graph.add_edges/2","doc":"This function is like `add_edge/3`, but for multiple edges at once, it also accepts edge specifications\nin a few different ways to make it easy to generate graphs succinctly.\n\nEdges must be provided as a list of `Edge` structs, `{vertex, vertex}` pairs, or\n`{vertex, vertex, edge_opts :: [label: term, weight: integer]}`.\n\nSee the docs for `Graph.Edge.new/2` or `Graph.Edge.new/3` for more info on creating Edge structs, and\n`add_edge/3` for information on edge options.\n\nIf an invalid edge specification is provided, raises `Graph.EdgeSpecificationError`.","ref":"Graph.html#add_edges/2"},{"type":"function","title":"Examples - Graph.add_edges/2","doc":"iex> alias Graph.Edge\n    ...> edges = [Edge.new(:a, :b), Edge.new(:b, :c, weight: 2)]\n    ...> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edges(edges)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b}, %Graph.Edge{v1: :b, v2: :c, weight: 2}]\n\n    iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:a, :b, label: :foo, weight: 2}])\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo, weight: 2}, %Graph.Edge{v1: :a, v2: :b}]\n\n    iex> Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edges([:a, :b])\n    ** (Graph.EdgeSpecificationError) Expected a valid edge specification, but got: :a","ref":"Graph.html#add_edges/2-examples"},{"type":"function","title":"Graph.add_vertex/3","doc":"Adds a new vertex to the graph. If the vertex is already present in the graph, the add is a no-op.\n\nYou can provide optional labels for the vertex, aside from the variety of uses this has for working\nwith graphs, labels will also be used when exporting a graph in DOT format.","ref":"Graph.html#add_vertex/3"},{"type":"function","title":"Example - Graph.add_vertex/3","doc":"iex> g = Graph.new |> Graph.add_vertex(:a, :mylabel) |> Graph.add_vertex(:a)\n    ...> [:a] = Graph.vertices(g)\n    ...> Graph.vertex_labels(g, :a)\n    [:mylabel]\n\n    iex> g = Graph.new |> Graph.add_vertex(:a, [:mylabel, :other])\n    ...> Graph.vertex_labels(g, :a)\n    [:mylabel, :other]","ref":"Graph.html#add_vertex/3-example"},{"type":"function","title":"Graph.add_vertices/2","doc":"Like `add_vertex/2`, but takes a list of vertices to add to the graph.","ref":"Graph.html#add_vertices/2"},{"type":"function","title":"Example - Graph.add_vertices/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :a])\n    ...> Graph.vertices(g)\n    [:a, :b]","ref":"Graph.html#add_vertices/2-example"},{"type":"function","title":"Graph.arborescence_root/1","doc":"Returns the root vertex of the arborescence, if one exists, otherwise nil.","ref":"Graph.html#arborescence_root/1"},{"type":"function","title":"Graph.batch_topsort/1","doc":"Returns a batch topological ordering of the vertices of graph `g`, if such an ordering exists, otherwise it\nreturns false. For each vertex in the returned list, no out-neighbors occur earlier in the list. This differs\nfrom `topsort/1` in that this function returns a list of lists where each sublist can be concurrently evaluated\nwithout worrying about elements in the sublist depending on eachother.\n\nMultiple edges between two vertices are considered a single edge for purposes of this sort.","ref":"Graph.html#batch_topsort/1"},{"type":"function","title":"Example - Graph.batch_topsort/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}])\n    ...> Graph.batch_topsort(g)\n    [[:a], [:b, :c]]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}])\n    ...> Graph.batch_topsort(g)\n    [[:a], [:b], [:c], [:d]]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d, :x, :y, :z])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:c, :d}, {:x, :y}, {:x, :z}])\n    ...> Graph.batch_topsort(g)\n    [[:a, :x], [:b, :c, :y, :z], [:d]]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d, :x, :y, :z])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}, {:c, :a}])\n    ...> Graph.batch_topsort(g)\n    false","ref":"Graph.html#batch_topsort/1-example"},{"type":"function","title":"Graph.bellman_ford/2","doc":"","ref":"Graph.html#bellman_ford/2"},{"type":"function","title":"Example - Graph.bellman_ford/2","doc":"iex> g = Graph.new |> Graph.add_edges([\n    ...>   {:b, :c, weight: -2}, {:a, :b, weight: 1},\n    ...>   {:c, :d, weight: 3}, {:b, :d, weight: 4}])\n    ...> Graph.bellman_ford(g, :a)\n    %{a: 0, b: 1, c: -1, d: 2}\n\n    iex> g = Graph.new |> Graph.add_edges([\n    ...>   {:b, :c, weight: -2}, {:a, :b, weight: -1},\n    ...>   {:c, :d, weight: -3}, {:d, :a, weight: -5}])\n    ...> Graph.bellman_ford(g, :a)\n    nil","ref":"Graph.html#bellman_ford/2-example"},{"type":"function","title":"Graph.cliques/1","doc":"Detects all maximal cliques in the provided graph.\n\nReturns a list of cliques, where each clique is a list of vertices in the clique.\n\nA clique is a subset `vs` of the vertices in the given graph, which together form a complete graph;\nor put another way, every vertex in `vs` is connected to all other vertices in `vs`.","ref":"Graph.html#cliques/1"},{"type":"function","title":"Graph.components/1","doc":"Returns a list of connected components, where each component is a list of vertices.\n\nA *connected component* is a maximal subgraph such that there is a path between each pair of vertices,\nconsidering all edges undirected.\n\nA *subgraph* is a graph whose vertices and edges are a subset of the vertices and edges of the source graph.\n\nA *maximal subgraph* is a subgraph with property `P` where all other subgraphs which contain the same vertices\ndo not have that same property `P`.","ref":"Graph.html#components/1"},{"type":"function","title":"Example - Graph.components/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}, {:c, :a}])\n    ...> Graph.components(g)\n    [[:d, :b, :c, :a]]","ref":"Graph.html#components/1-example"},{"type":"function","title":"Graph.coreness/2","doc":"Calculates the k-coreness of vertex `v` in graph `g`.\n\nThe k-coreness of a vertex is defined as the maximum value of `k`\nfor which `v` is found in the corresponding k-core of graph `g`.\n\nNOTE: This function decomposes all k-core components to determine the coreness\nof a vertex - if you will be trying to determine the coreness of many vertices,\nit is recommended to use `k_core_components/1` and then lookup the coreness of a vertex\nby querying the resulting map.","ref":"Graph.html#coreness/2"},{"type":"function","title":"Graph.degeneracy/1","doc":"Determines the k-degeneracy of the given graph.\n\nThe degeneracy of graph `g` is the maximum value of `k` for which a k-core\nexists in graph `g`.","ref":"Graph.html#degeneracy/1"},{"type":"function","title":"Graph.degeneracy_core/1","doc":"Calculates the degeneracy core of a given graph.\n\nThe degeneracy core of a graph is the k-core of the graph where the\nvalue of `k` is the degeneracy of the graph. The degeneracy of a graph\nis the highest value of `k` which has a non-empty k-core in the graph.","ref":"Graph.html#degeneracy_core/1"},{"type":"function","title":"Graph.degree/2","doc":"Returns the degree of vertex `v` of graph `g`.\n\nThe degree of a vertex is the total number of edges containing that vertex.\n\nFor directed graphs this is the same as the sum of the in-degree and out-degree\nof the given vertex. For undirected graphs, the in-degree and out-degree are always\nthe same.","ref":"Graph.html#degree/2"},{"type":"function","title":"Example - Graph.degree/2","doc":"iex> g = Graph.new(type: :undirected) |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b)\n    ...> Graph.degree(g, :b)\n    1\n\n    iex> g = Graph.new() |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b)\n    ...> Graph.degree(g, :b)\n    1","ref":"Graph.html#degree/2-example"},{"type":"function","title":"Graph.delete_edge/3","doc":"Removes all edges connecting `v1` to `v2`, regardless of label.\n\nIf no such edge exists, the graph is returned unmodified.","ref":"Graph.html#delete_edge/3"},{"type":"function","title":"Example - Graph.delete_edge/3","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}])\n  ...> g = Graph.delete_edge(g, :a, :b)\n  ...> [:a, :b] = Graph.vertices(g)\n  ...> Graph.edges(g)\n  []\n\n  iex> g = Graph.new(type: :undirected) |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}])\n  ...> g = Graph.delete_edge(g, :a, :b)\n  ...> [:a, :b] = Graph.vertices(g)\n  ...> Graph.edges(g)\n  []","ref":"Graph.html#delete_edge/3-example"},{"type":"function","title":"Graph.delete_edge/4","doc":"Removes an edge connecting `v1` to `v2`. A label can be specified to disambiguate the\nspecific edge you wish to delete, if not provided, the unlabelled edge, if one exists,\nwill be removed.\n\nIf no such edge exists, the graph is returned unmodified.","ref":"Graph.html#delete_edge/4"},{"type":"function","title":"Example - Graph.delete_edge/4","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}])\n    ...> g = Graph.delete_edge(g, :a, :b, nil)\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo}]\n\n    iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}])\n    ...> g = Graph.delete_edge(g, :a, :b, :foo)\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: nil}]\n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}])\n    ...> g = Graph.delete_edge(g, :a, :b, :foo)\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: nil}]","ref":"Graph.html#delete_edge/4-example"},{"type":"function","title":"Graph.delete_edges/2","doc":"Like `delete_edge/3`, but takes a list of edge specifications, and deletes the corresponding\nedges from the graph, if they exist.\n\nEdge specifications can be `Edge` structs, `{vertex, vertex}` pairs, or `{vertex, vertex, label: label}`\ntriplets. An invalid specification will cause `Graph.EdgeSpecificationError` to be raised.","ref":"Graph.html#delete_edges/2"},{"type":"function","title":"Examples - Graph.delete_edges/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b)\n    ...> g = Graph.delete_edges(g, [{:a, :b}])\n    ...> Graph.edges(g)\n    []\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b, label: :foo)\n    ...> g = Graph.delete_edges(g, [{:a, :b}])\n    ...> Graph.edges(g)\n    []\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b, label: :foo)\n    ...> g = Graph.delete_edges(g, [{:a, :b, label: :bar}])\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo}]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b, label: :foo)\n    ...> g = Graph.delete_edges(g, [{:a, :b, label: :foo}])\n    ...> Graph.edges(g)\n    []\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b)\n    ...> Graph.delete_edges(g, [:a])\n    ** (Graph.EdgeSpecificationError) Expected a valid edge specification, but got: :a","ref":"Graph.html#delete_edges/2-examples"},{"type":"function","title":"Graph.delete_edges/3","doc":"This function can be used to remove all edges between `v1` and `v2`. This is useful if\nyou are defining multiple edges between vertices to represent different relationships, but\nwant to remove them all as if they are a single unit.","ref":"Graph.html#delete_edges/3"},{"type":"function","title":"Examples - Graph.delete_edges/3","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:b, :a}])\n    ...> g = Graph.delete_edges(g, :a, :b)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :b, v2: :a}]\n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:b, :a}])\n    ...> g = Graph.delete_edges(g, :a, :b)\n    ...> Graph.edges(g)\n    []","ref":"Graph.html#delete_edges/3-examples"},{"type":"function","title":"Graph.delete_vertex/2","doc":"Removes a vertex from the graph, as well as any edges which refer to that vertex. If the vertex does\nnot exist in the graph, it is a no-op.","ref":"Graph.html#delete_vertex/2"},{"type":"function","title":"Example - Graph.delete_vertex/2","doc":"iex> g = Graph.new |> Graph.add_vertex(:a) |> Graph.add_vertex(:b) |> Graph.add_edge(:a, :b)\n    ...> [:a, :b] = Graph.vertices(g)\n    ...> [%Graph.Edge{v1: :a, v2: :b}] = Graph.edges(g)\n    ...> g = Graph.delete_vertex(g, :b)\n    ...> [:a] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    []","ref":"Graph.html#delete_vertex/2-example"},{"type":"function","title":"Graph.delete_vertices/2","doc":"Like `delete_vertex/2`, but takes a list of vertices to delete from the graph.","ref":"Graph.html#delete_vertices/2"},{"type":"function","title":"Example - Graph.delete_vertices/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.delete_vertices([:a, :b])\n    ...> Graph.vertices(g)\n    [:c]","ref":"Graph.html#delete_vertices/2-example"},{"type":"function","title":"Graph.dijkstra/3","doc":"Gets the shortest path between `a` and `b`.\n\nAs indicated by the name, this uses Dijkstra's algorithm for locating the shortest path, which\nmeans that edge weights are taken into account when determining which vertices to search next. By\ndefault, all edges have a weight of 1, so vertices are inspected at random; which causes this algorithm\nto perform a naive depth-first search of the graph until a path is found. If your edges are weighted however,\nthis will allow the algorithm to more intelligently navigate the graph.","ref":"Graph.html#dijkstra/3"},{"type":"function","title":"Example - Graph.dijkstra/3","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :c}, {:c, :d}, {:b, :d}])\n    ...> Graph.dijkstra(g, :a, :d)\n    [:a, :b, :d]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :c}, {:b, :c}, {:b, :d}])\n    ...> Graph.dijkstra(g, :a, :d)\n    nil","ref":"Graph.html#dijkstra/3-example"},{"type":"function","title":"Graph.edge/3","doc":"Get an Edge struct for a specific vertex pair, or vertex pair + label.","ref":"Graph.html#edge/3"},{"type":"function","title":"Example - Graph.edge/3","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :contains}, {:a, :b, label: :uses}])\n    ...> Graph.edge(g, :b, :a)\n    nil\n\n    iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :contains}, {:a, :b, label: :uses}])\n    ...> Graph.edge(g, :a, :b)\n    %Graph.Edge{v1: :a, v2: :b}\n\n    iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :contains}, {:a, :b, label: :uses}])\n    ...> Graph.edge(g, :a, :b, :contains)\n    %Graph.Edge{v1: :a, v2: :b, label: :contains}\n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_edges([{:a, :b}, {:a, :b, label: :contains}, {:a, :b, label: :uses}])\n    ...> Graph.edge(g, :a, :b, :contains)\n    %Graph.Edge{v1: :a, v2: :b, label: :contains}","ref":"Graph.html#edge/3-example"},{"type":"function","title":"Graph.edge/4","doc":"","ref":"Graph.html#edge/4"},{"type":"type","title":"Graph.edge_key/0","doc":"","ref":"Graph.html#t:edge_key/0"},{"type":"type","title":"Graph.edge_value/0","doc":"","ref":"Graph.html#t:edge_value/0"},{"type":"type","title":"Graph.edge_weight/0","doc":"","ref":"Graph.html#t:edge_weight/0"},{"type":"function","title":"Graph.edges/1","doc":"Return a list of all the edges, where each edge is expressed as a tuple\nof `{A, B}`, where the elements are the vertices involved, and implying the\ndirection of the edge to be from `A` to `B`.\n\nNOTE: You should be careful when using this on dense graphs, as it produces\nlists with whatever you've provided as vertices, with likely many copies of\neach. I'm not sure if those copies are shared in-memory as they are unchanged,\nso it *should* be fairly compact in memory, but I have not verified that to be sure.","ref":"Graph.html#edges/1"},{"type":"function","title":"Example - Graph.edges/1","doc":"iex> g = Graph.new |> Graph.add_vertex(:a) |> Graph.add_vertex(:b) |> Graph.add_vertex(:c)\n    ...> g = g |> Graph.add_edge(:a, :c) |> Graph.add_edge(:b, :c)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :c}, %Graph.Edge{v1: :b, v2: :c}]","ref":"Graph.html#edges/1-example"},{"type":"function","title":"Graph.edges/2","doc":"Returns a list of all edges inbound or outbound from vertex `v`.","ref":"Graph.html#edges/2"},{"type":"function","title":"Example - Graph.edges/2","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :c}])\n    ...> Graph.edges(g, :b)\n    [%Graph.Edge{v1: :a, v2: :b}, %Graph.Edge{v1: :b, v2: :c}]\n\n    iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :c}])\n    ...> Graph.edges(g, :d)\n    []","ref":"Graph.html#edges/2-example"},{"type":"function","title":"Graph.edges/3","doc":"Returns a list of all edges between `v1` and `v2`.","ref":"Graph.html#edges/3"},{"type":"function","title":"Example - Graph.edges/3","doc":"iex> g = Graph.new |> Graph.add_edge(:a, :b, label: :uses)\n    ...> g = Graph.add_edge(g, :a, :b, label: :contains)\n    ...> Graph.edges(g, :a, :b)\n    [%Graph.Edge{v1: :a, v2: :b, label: :contains}, %Graph.Edge{v1: :a, v2: :b, label: :uses}]\n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_edge(:a, :b, label: :uses)\n    ...> g = Graph.add_edge(g, :a, :b, label: :contains)\n    ...> Graph.edges(g, :a, :b)\n    [%Graph.Edge{v1: :a, v2: :b, label: :contains}, %Graph.Edge{v1: :a, v2: :b, label: :uses}]","ref":"Graph.html#edges/3-example"},{"type":"function","title":"Graph.get_paths/3","doc":"Builds a list of paths between vertex `a` and vertex `b`.\n\nThe algorithm used here is a depth-first search, which evaluates the whole\ngraph until all paths are found. Order is guaranteed to be deterministic,\nbut not guaranteed to be in any meaningful order (i.e. shortest to longest).","ref":"Graph.html#get_paths/3"},{"type":"function","title":"Example - Graph.get_paths/3","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :c}, {:c, :d}, {:b, :d}, {:c, :a}])\n    ...> Graph.get_paths(g, :a, :d)\n    [[:a, :b, :c, :d], [:a, :b, :d]]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :c}, {:b, :c}, {:b, :d}])\n    ...> Graph.get_paths(g, :a, :d)\n    []","ref":"Graph.html#get_paths/3-example"},{"type":"function","title":"Graph.get_shortest_path/3","doc":"See `dijkstra/3`.","ref":"Graph.html#get_shortest_path/3"},{"type":"type","title":"Graph.graph_info/0","doc":"","ref":"Graph.html#t:graph_info/0"},{"type":"type","title":"Graph.graph_type/0","doc":"","ref":"Graph.html#t:graph_type/0"},{"type":"function","title":"Graph.has_vertex?/2","doc":"Returns true if the given vertex exists in the graph. Otherwise false.","ref":"Graph.html#has_vertex?/2"},{"type":"function","title":"Example - Graph.has_vertex?/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b])\n    ...> Graph.has_vertex?(g, :a)\n    true\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b])\n    ...> Graph.has_vertex?(g, :c)\n    false","ref":"Graph.html#has_vertex?/2-example"},{"type":"function","title":"Graph.in_degree/2","doc":"Returns the in-degree of vertex `v` of graph `g`.\n\nThe *in-degree* of a vertex is the number of edges directed inbound towards that vertex.\n\nFor undirected graphs, the in-degree and out-degree are always the same - the sum total\nof all edges inbound or outbound from the vertex.","ref":"Graph.html#in_degree/2"},{"type":"function","title":"Example - Graph.in_degree/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b)\n    ...> Graph.in_degree(g, :b)\n    1","ref":"Graph.html#in_degree/2-example"},{"type":"function","title":"Graph.in_edges/2","doc":"Returns a list of `Graph.Edge` structs representing the in edges to vertex `v`.\n\nIn the case of undirected graphs, it delegates to `edges/2`.","ref":"Graph.html#in_edges/2"},{"type":"function","title":"Example - Graph.in_edges/2","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:b, :c}])\n    ...> Graph.in_edges(g, :b)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo}, %Graph.Edge{v1: :a, v2: :b}]","ref":"Graph.html#in_edges/2-example"},{"type":"function","title":"Graph.in_neighbors/2","doc":"Returns a list of vertices which all have edges coming in to the given vertex `v`.\n\nIn the case of undirected graphs, it delegates to `neighbors/2`.","ref":"Graph.html#in_neighbors/2"},{"type":"function","title":"Example - Graph.in_neighbors/2","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:b, :c}])\n    ...> Graph.in_neighbors(g, :b)\n    [:a]","ref":"Graph.html#in_neighbors/2-example"},{"type":"function","title":"Graph.info/1","doc":"Returns a map of summary information about this graph.\n\nNOTE: The `size_in_bytes` value is an estimate, not a perfectly precise value, but\nshould be close enough to be useful.","ref":"Graph.html#info/1"},{"type":"function","title":"Example - Graph.info/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = g |> Graph.add_edges([{:a, :b}, {:b, :c}])\n    ...> match?(%{type: :directed, num_vertices: 4, num_edges: 2}, Graph.info(g))\n    true","ref":"Graph.html#info/1-example"},{"type":"function","title":"Graph.is_acyclic?/1","doc":"Returns true if and only if the graph `g` is acyclic.","ref":"Graph.html#is_acyclic?/1"},{"type":"function","title":"Graph.is_arborescence?/1","doc":"Returns true if the graph is an aborescence, a directed acyclic graph,\nwhere the *root*, a vertex, of the arborescence has a unique path from itself\nto every other vertex in the graph.","ref":"Graph.html#is_arborescence?/1"},{"type":"function","title":"Graph.is_cyclic?/1","doc":"Returns true if the graph `g` is not acyclic.","ref":"Graph.html#is_cyclic?/1"},{"type":"function","title":"Graph.is_subgraph?/2","doc":"Returns true if graph `g1` is a subgraph of `g2`.\n\nA graph is a subgraph of another graph if it's vertices and edges\nare a subset of that graph's vertices and edges.","ref":"Graph.html#is_subgraph?/2"},{"type":"function","title":"Example - Graph.is_subgraph?/2","doc":"iex> g1 = Graph.new |> Graph.add_vertices([:a, :b, :c, :d]) |> Graph.add_edge(:a, :b) |> Graph.add_edge(:b, :c)\n    ...> g2 = Graph.new |> Graph.add_vertices([:b, :c]) |> Graph.add_edge(:b, :c)\n    ...> Graph.is_subgraph?(g2, g1)\n    true\n\n    iex> g1 = Graph.new |> Graph.add_vertices([:a, :b, :c, :d]) |> Graph.add_edges([{:a, :b}, {:b, :c}])\n    ...> g2 = Graph.new |> Graph.add_vertices([:b, :c, :e]) |> Graph.add_edges([{:b, :c}, {:c, :e}])\n    ...> Graph.is_subgraph?(g2, g1)\n    false","ref":"Graph.html#is_subgraph?/2-example"},{"type":"function","title":"Graph.is_tree?/1","doc":"Returns true if and only if the graph `g` is a tree.\n\nThis function always returns false for undirected graphs.\n\nNOTE: Multiple edges between the same pair of vertices in the same direction are\nconsidered a single edge when determining if the provided graph is a tree.","ref":"Graph.html#is_tree?/1"},{"type":"function","title":"Graph.k_cliques/2","doc":"Detects all maximal cliques of degree `k`.\n\nReturns a list of cliques, where each clique is a list of vertices in the clique.","ref":"Graph.html#k_cliques/2"},{"type":"function","title":"Graph.k_core/2","doc":"Calculates the k-core for a given graph and value of `k`.\n\nA k-core of the graph is a maximal subgraph of `g` which contains vertices of which all\nhave a degree of at least `k`. This function returns a new `Graph` which is a subgraph\nof `g` containing all vertices which have a coreness >= the desired value of `k`.\n\nIf there is no k-core in the graph for the provided value of `k`, an empty `Graph` is returned.\n\nIf a negative integer is provided for `k`, a RuntimeError will be raised.\n\nNOTE: For performance reasons, k-core calculations make use of ETS. If you are\nsensitive to the number of concurrent ETS tables running in your system, you should\nbe aware of it's usage here. 2 tables are used, and they are automatically cleaned\nup when this function returns.","ref":"Graph.html#k_core/2"},{"type":"function","title":"Graph.k_core_components/1","doc":"Groups all vertices by their k-coreness into a single map.\n\nMore commonly you will want a specific k-core, in particular the degeneracy core,\nfor which there are other functions in the API you can use. However if you have\na need to determine which k-core each vertex belongs to, this function can be used\nto do just that.\n\nAs an example, you can construct the k-core for a given graph like so:\n\n    k_core_vertices =\n      g\n      |> Graph.k_core_components()\n      |> Stream.filter(fn {k, _} -> k >= desired_k end)\n      |> Enum.flat_map(fn {_, vs} -> vs end)\n    Graph.subgraph(g, k_core_vertices)","ref":"Graph.html#k_core_components/1"},{"type":"type","title":"Graph.label/0","doc":"","ref":"Graph.html#t:label/0"},{"type":"function","title":"Graph.label_vertex/3","doc":"Updates the labels for the given vertex.\n\nIf no such vertex exists in the graph, `{:error, {:invalid_vertex, v}}` is returned.","ref":"Graph.html#label_vertex/3"},{"type":"function","title":"Example - Graph.label_vertex/3","doc":"iex> g = Graph.new |> Graph.add_vertex(:a, :foo)\n    ...> [:foo] = Graph.vertex_labels(g, :a)\n    ...> g = Graph.label_vertex(g, :a, :bar)\n    ...> Graph.vertex_labels(g, :a)\n    [:foo, :bar]\n\n    iex> g = Graph.new |> Graph.add_vertex(:a)\n    ...> g = Graph.label_vertex(g, :a, [:foo, :bar])\n    ...> Graph.vertex_labels(g, :a)\n    [:foo, :bar]","ref":"Graph.html#label_vertex/3-example"},{"type":"function","title":"Graph.loop_vertices/1","doc":"Returns a list of vertices from graph `g` which are included in a loop, where a loop is a cycle of length 1.","ref":"Graph.html#loop_vertices/1"},{"type":"function","title":"Example - Graph.loop_vertices/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :a)\n    ...> Graph.loop_vertices(g)\n    [:a]","ref":"Graph.html#loop_vertices/1-example"},{"type":"function","title":"Graph.neighbors/2","doc":"Return all neighboring vertices of the given vertex.","ref":"Graph.html#neighbors/2"},{"type":"function","title":"Example - Graph.neighbors/2","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :a}, {:b, :c}, {:c, :a}])\n    ...> Graph.neighbors(g, :a)\n    [:b, :c]\n\n    iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:b, :a}, {:b, :c}, {:c, :a}])\n    ...> Graph.neighbors(g, :d)\n    []","ref":"Graph.html#neighbors/2-example"},{"type":"function","title":"Graph.new/1","doc":"Creates a new graph using the provided options.","ref":"Graph.html#new/1"},{"type":"function","title":"Options - Graph.new/1","doc":"- `type: :directed | :undirected`, specifies what type of graph this is. Defaults to a `:directed` graph.\n- `vertex_identifier`: a function which accepts a vertex and returns a unique identifier of said vertex.\n  Defaults to `Graph.Utils.vertex_id/1`, a hash of the whole vertex utilizing `:erlang.phash2/2`.","ref":"Graph.html#new/1-options"},{"type":"function","title":"Example - Graph.new/1","doc":"iex> Graph.new()\n    #Graph \n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_edges([{:a, :b}, {:b, :a}])\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b}]\n\n    iex> g = Graph.new(type: :directed) |> Graph.add_edges([{:a, :b}, {:b, :a}])\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b}, %Graph.Edge{v1: :b, v2: :a}]\n\n    iex> g = Graph.new(vertex_identifier: fn v -> :erlang.phash2(v) end) |> Graph.add_edges([{:a, :b}, {:b, :a}])\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b}, %Graph.Edge{v1: :b, v2: :a}]","ref":"Graph.html#new/1-example"},{"type":"function","title":"Graph.num_edges/1","doc":"Returns the number of edges in the graph.\n\nPseudo-edges (label/weight pairs applied to an edge) are not counted, only distinct\nvertex pairs where an edge exists between them are counted.","ref":"Graph.html#num_edges/1"},{"type":"function","title":"Example - Graph.num_edges/1","doc":"iex> g = Graph.add_edges(Graph.new, [{:a, :b}, {:b, :c}, {:a, :a}])\n    ...> Graph.num_edges(g)\n    3","ref":"Graph.html#num_edges/1-example"},{"type":"function","title":"Graph.num_vertices/1","doc":"Returns the number of vertices in the graph","ref":"Graph.html#num_vertices/1"},{"type":"function","title":"Example - Graph.num_vertices/1","doc":"iex> g = Graph.add_vertices(Graph.new, [:a, :b, :c])\n    ...> Graph.num_vertices(g)\n    3","ref":"Graph.html#num_vertices/1-example"},{"type":"function","title":"Graph.out_degree/2","doc":"Returns the out-degree of vertex `v` of graph `g`.\n\nThe *out-degree* of a vertex is the number of edges directed outbound from that vertex.\n\nFor undirected graphs, the in-degree and out-degree are always the same - the sum total\nof all edges inbound or outbound from the vertex.","ref":"Graph.html#out_degree/2"},{"type":"function","title":"Example - Graph.out_degree/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b)\n    ...> Graph.out_degree(g, :a)\n    1","ref":"Graph.html#out_degree/2-example"},{"type":"function","title":"Graph.out_edges/2","doc":"Returns a list of `Graph.Edge` structs representing the out edges from vertex `v`.\n\nIn the case of undirected graphs, it delegates to `edges/2`.","ref":"Graph.html#out_edges/2"},{"type":"function","title":"Example - Graph.out_edges/2","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:b, :c}])\n    ...> Graph.out_edges(g, :a)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo}, %Graph.Edge{v1: :a, v2: :b}]","ref":"Graph.html#out_edges/2-example"},{"type":"function","title":"Graph.out_neighbors/2","doc":"Returns a list of vertices which the given vertex `v` has edges going to.\n\nIn the case of undirected graphs, it delegates to `neighbors/2`.","ref":"Graph.html#out_neighbors/2"},{"type":"function","title":"Example - Graph.out_neighbors/2","doc":"iex> g = Graph.new |> Graph.add_edges([{:a, :b}, {:a, :b, label: :foo}, {:b, :c}])\n    ...> Graph.out_neighbors(g, :a)\n    [:b]","ref":"Graph.html#out_neighbors/2-example"},{"type":"function","title":"Graph.postorder/1","doc":"Returns all vertices of graph `g`. The order is given by a depth-first traversal of the graph,\ncollecting visited vertices in postorder. More precisely, the vertices visited while searching from an\narbitrarily chosen vertex are collected in postorder, and all those collected vertices are placed before\nthe subsequently visited vertices.","ref":"Graph.html#postorder/1"},{"type":"function","title":"Example - Graph.postorder/1","doc":"Our example code constructs a graph which looks like so:\n\n        :a\n                     :b\n          /           :c   :d\n        /\n       :e\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d, :e])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:b, :c}, {:b, :d}, {:c, :e}])\n    ...> Graph.postorder(g)\n    [:e, :c, :d, :b, :a]","ref":"Graph.html#postorder/1-example"},{"type":"function","title":"Graph.preorder/1","doc":"Returns all vertices of graph `g`. The order is given by a depth-first traversal of the graph,\ncollecting visited vertices in preorder.","ref":"Graph.html#preorder/1"},{"type":"function","title":"Example - Graph.preorder/1","doc":"Our example code constructs a graph which looks like so:\n\n         :a\n                       :b\n           /           :c   :d\n         /\n       :e\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d, :e])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:b, :c}, {:b, :d}, {:c, :e}])\n    ...> Graph.preorder(g)\n    [:a, :b, :c, :e, :d]","ref":"Graph.html#preorder/1-example"},{"type":"function","title":"Graph.reachable/2","doc":"Returns an unsorted list of vertices from the graph, such that for each vertex in the list (call it `v`),\nthere is a path in the graph from some vertex of `vs` to `v`.\n\nAs paths of length zero are allowed, the vertices of `vs` are also included in the returned list.","ref":"Graph.html#reachable/2"},{"type":"function","title":"Example - Graph.reachable/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}])\n    ...> Graph.reachable(g, [:a])\n    [:d, :c, :b, :a]","ref":"Graph.html#reachable/2-example"},{"type":"function","title":"Graph.reachable_neighbors/2","doc":"Returns an unsorted list of vertices from the graph, such that for each vertex in the list (call it `v`),\nthere is a path in the graph of length one or more from some vertex of `vs` to `v`.\n\nAs a consequence, only those vertices of `vs` that are included in some cycle are returned.","ref":"Graph.html#reachable_neighbors/2"},{"type":"function","title":"Example - Graph.reachable_neighbors/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}])\n    ...> Graph.reachable_neighbors(g, [:a])\n    [:d, :c, :b]","ref":"Graph.html#reachable_neighbors/2-example"},{"type":"function","title":"Graph.reaching/2","doc":"Returns an unsorted list of vertices from the graph, such that for each vertex in the list (call it `v`),\nthere is a path from `v` to some vertex of `vs`.\n\nAs paths of length zero are allowed, the vertices of `vs` are also included in the returned list.","ref":"Graph.html#reaching/2"},{"type":"function","title":"Example - Graph.reaching/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}])\n    ...> Graph.reaching(g, [:d])\n    [:b, :a, :c, :d]","ref":"Graph.html#reaching/2-example"},{"type":"function","title":"Graph.reaching_neighbors/2","doc":"Returns an unsorted list of vertices from the graph, such that for each vertex in the list (call it `v`),\nthere is a path of length one or more from `v` to some vertex of `vs`.\n\nAs a consequence, only those vertices of `vs` that are included in some cycle are returned.","ref":"Graph.html#reaching_neighbors/2"},{"type":"function","title":"Example - Graph.reaching_neighbors/2","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :a}, {:b, :d}])\n    ...> Graph.reaching_neighbors(g, [:b])\n    [:b, :c, :a]","ref":"Graph.html#reaching_neighbors/2-example"},{"type":"function","title":"Graph.remove_vertex_labels/2","doc":"iex> graph = Graph.new |> Graph.add_vertex(:a, [:foo, :bar])\n  ...> [:foo, :bar] = Graph.vertex_labels(graph, :a)\n  ...> graph = Graph.remove_vertex_labels(graph, :a)\n  ...> Graph.vertex_labels(graph, :a)\n  []\n\n  iex> graph = Graph.new |> Graph.add_vertex(:a, [:foo, :bar])\n  ...> [:foo, :bar] = Graph.vertex_labels(graph, :a)\n  ...> Graph.remove_vertex_labels(graph, :b)\n  {:error, {:invalid_vertex, :b}}","ref":"Graph.html#remove_vertex_labels/2"},{"type":"function","title":"Graph.replace_vertex/3","doc":"Replaces `vertex` with `new_vertex` in the graph.","ref":"Graph.html#replace_vertex/3"},{"type":"function","title":"Example - Graph.replace_vertex/3","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:b, :c}, {:c, :a}, {:c, :d}])\n    ...> [:a, :b, :c, :d] = Graph.vertices(g)\n    ...> g = Graph.replace_vertex(g, :a, :e)\n    ...> [:b, :c, :d, :e] = Graph.vertices(g)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :b, v2: :c}, %Graph.Edge{v1: :c, v2: :d}, %Graph.Edge{v1: :c, v2: :e}, %Graph.Edge{v1: :e, v2: :b}]","ref":"Graph.html#replace_vertex/3-example"},{"type":"function","title":"Graph.split_edge/4","doc":"Splits the edges between `v1` and `v2` by inserting a new vertex, `v3`, deleting\nthe edges between `v1` and `v2`, and inserting new edges from `v1` to `v3` and from\n`v3` to `v2`.\n\nThe resulting edges from the split will share the same weight and label as the old edges.","ref":"Graph.html#split_edge/4"},{"type":"function","title":"Example - Graph.split_edge/4","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :c]) |> Graph.add_edge(:a, :c, weight: 2)\n    ...> g = Graph.split_edge(g, :a, :c, :b)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, weight: 2}, %Graph.Edge{v1: :b, v2: :c, weight: 2}]\n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_vertices([:a, :c]) |> Graph.add_edge(:a, :c, weight: 2)\n    ...> g = Graph.split_edge(g, :a, :c, :b)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, weight: 2}, %Graph.Edge{v1: :b, v2: :c, weight: 2}]","ref":"Graph.html#split_edge/4-example"},{"type":"function","title":"Graph.strong_components/1","doc":"Returns a list of strongly connected components, where each component is a list of vertices.\n\nA *strongly connected component* is a maximal subgraph such that there is a path between each pair of vertices.\n\nSee `components/1` for the definitions of *subgraph* and *maximal subgraph* if you are unfamiliar with the\nterminology.","ref":"Graph.html#strong_components/1"},{"type":"function","title":"Example - Graph.strong_components/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}, {:c, :a}])\n    ...> Graph.strong_components(g)\n    [[:d], [:b, :c, :a]]","ref":"Graph.html#strong_components/1-example"},{"type":"function","title":"Graph.subgraph/2","doc":"Builds a maximal subgraph of `g` which includes all of the vertices in `vs` and the edges which connect them.\n\nSee the test suite for example usage.","ref":"Graph.html#subgraph/2"},{"type":"type","title":"Graph.t/0","doc":"","ref":"Graph.html#t:t/0"},{"type":"function","title":"Graph.to_dot/1","doc":"Converts the given Graph to DOT format, which can then be converted to\na number of other formats via Graphviz, e.g. `dot -Tpng out.dot > out.png`.\n\nIf labels are set on a vertex, then those labels are used in the DOT output\nin place of the vertex itself. If no labels were set, then the vertex is\nstringified if it's a primitive type and inspected if it's not, in which\ncase the inspect output will be quoted and used as the vertex label in the DOT file.\n\nEdge labels and weights will be shown as attributes on the edge definitions, otherwise\nthey use the same labelling scheme for the involved vertices as described above.\n\nNOTE: Currently this function assumes graphs are directed graphs, but in the future\nit will support undirected graphs as well.\n\nNOTE: Currently this function assumes graphs are directed graphs, but in the future\nit will support undirected graphs as well.\n\nNOTE 2: To avoid to overwrite vertices with the same label, output is\ngenerated using the internal numeric ID as vertex label.\nOriginal label is expressed as `id[label=\" \"]`.","ref":"Graph.html#to_dot/1"},{"type":"function","title":"Example - Graph.to_dot/1","doc":"> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    > g = Graph.add_edges(g, [{:a, :b}, {:b, :c}, {:b, :d}, {:c, :d}])\n    > g = Graph.label_vertex(g, :a, :start)\n    > g = Graph.label_vertex(g, :d, :finish)\n    > g = Graph.update_edge(g, :b, :d, weight: 3)\n    > {:ok, dot} = Graph.to_dot(g)\n    > IO.puts(dot)\n    strict digraph {\n        97[label=\"start\"]\n        98[label=\"b\"]\n        99[label=\"c\"]\n        100[label=\"finish\"]\n        97 -> 98 [weight=1]\n        98 -> 99 [weight=1]\n        98 -> 100 [weight=3]\n        99 -> 100 [weight=1]\n    }","ref":"Graph.html#to_dot/1-example"},{"type":"function","title":"Graph.to_edgelist/1","doc":"","ref":"Graph.html#to_edgelist/1"},{"type":"function","title":"Graph.to_flowchart/1","doc":"","ref":"Graph.html#to_flowchart/1"},{"type":"function","title":"Graph.topsort/1","doc":"Returns a topological ordering of the vertices of graph `g`, if such an ordering exists, otherwise it returns false.\nFor each vertex in the returned list, no out-neighbors occur earlier in the list.\n\nMultiple edges between two vertices are considered a single edge for purposes of this sort.","ref":"Graph.html#topsort/1"},{"type":"function","title":"Example - Graph.topsort/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}])\n    ...> Graph.topsort(g)\n    [:a, :b, :c, :d]\n\n    iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c, :d])\n    ...> g = Graph.add_edges(g, [{:a, :b}, {:a, :c}, {:b, :c}, {:c, :d}, {:c, :a}])\n    ...> Graph.topsort(g)\n    false","ref":"Graph.html#topsort/1-example"},{"type":"function","title":"Graph.transpose/1","doc":"The transposition of a graph is another graph with the direction of all the edges reversed.","ref":"Graph.html#transpose/1"},{"type":"function","title":"Example - Graph.transpose/1","doc":"iex> g = Graph.new |> Graph.add_vertices([:a, :b, :c]) |> Graph.add_edge(:a, :b) |> Graph.add_edge(:b, :c)\n    ...> g |> Graph.transpose |> Graph.edges\n    [%Graph.Edge{v1: :b, v2: :a}, %Graph.Edge{v1: :c, v2: :b}]","ref":"Graph.html#transpose/1-example"},{"type":"function","title":"Graph.update_edge/4","doc":"Given two vertices, this function updates the metadata (weight/label) for the unlabelled\nedge between those two vertices. If no unlabelled edge exists between them, an error\ntuple is returned. If you set a label, the unlabelled edge will be replaced with a new labelled\nedge.","ref":"Graph.html#update_edge/4"},{"type":"function","title":"Example - Graph.update_edge/4","doc":"iex> g = Graph.new |> Graph.add_edge(:a, :b) |> Graph.add_edge(:a, :b, label: :bar)\n    ...> %Graph{} = g = Graph.update_edge(g, :a, :b, weight: 2, label: :foo)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :bar}, %Graph.Edge{v1: :a, v2: :b, label: :foo, weight: 2}]","ref":"Graph.html#update_edge/4-example"},{"type":"function","title":"Graph.update_labelled_edge/5","doc":"Like `update_edge/4`, but requires you to specify the labelled edge to update.\n\nTh implementation of `update_edge/4` is actually `update_edge(g, v1, v2, nil, opts)`.","ref":"Graph.html#update_labelled_edge/5"},{"type":"function","title":"Example - Graph.update_labelled_edge/5","doc":"iex> g = Graph.new |> Graph.add_edge(:a, :b) |> Graph.add_edge(:a, :b, label: :bar)\n    ...> %Graph{} = g = Graph.update_labelled_edge(g, :a, :b, :bar, weight: 2, label: :foo)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo, weight: 2}, %Graph.Edge{v1: :a, v2: :b}]\n\n    iex> g = Graph.new(type: :undirected) |> Graph.add_edge(:a, :b) |> Graph.add_edge(:a, :b, label: :bar)\n    ...> %Graph{} = g = Graph.update_labelled_edge(g, :a, :b, :bar, weight: 2, label: :foo)\n    ...> Graph.edges(g)\n    [%Graph.Edge{v1: :a, v2: :b, label: :foo, weight: 2}, %Graph.Edge{v1: :a, v2: :b}]","ref":"Graph.html#update_labelled_edge/5-example"},{"type":"type","title":"Graph.vertex/0","doc":"","ref":"Graph.html#t:vertex/0"},{"type":"type","title":"Graph.vertex_id/0","doc":"Identifier of a vertex. By default a non_neg_integer from `Graph.Utils.vertex_id/1` utilizing `:erlang.phash2`.","ref":"Graph.html#t:vertex_id/0"},{"type":"function","title":"Graph.vertex_labels/2","doc":"Returns the label for the given vertex.\nIf no label was assigned, it returns [].","ref":"Graph.html#vertex_labels/2"},{"type":"function","title":"Example - Graph.vertex_labels/2","doc":"iex> g = Graph.new |> Graph.add_vertex(:a) |> Graph.label_vertex(:a, :my_label)\n    ...> Graph.vertex_labels(g, :a)\n    [:my_label]","ref":"Graph.html#vertex_labels/2-example"},{"type":"type","title":"Graph.vertices/0","doc":"","ref":"Graph.html#t:vertices/0"},{"type":"function","title":"Graph.vertices/1","doc":"Returns a list of all the vertices in the graph.\n\nNOTE: You should be careful when using this on large graphs, as the list it produces\ncontains every vertex on the graph. I have not yet verified whether Erlang ensures that\nthey are a shared reference with the original, or copies, but if the latter it could result\nin running out of memory if the graph is too large.","ref":"Graph.html#vertices/1"},{"type":"function","title":"Example - Graph.vertices/1","doc":"iex> g = Graph.new |> Graph.add_vertex(:a) |> Graph.add_vertex(:b)\n    ...> Graph.vertices(g)\n    [:a, :b]","ref":"Graph.html#vertices/1-example"},{"type":"module","title":"Graph.Edge","doc":"This module defines the struct used to represent edges and associated metadata about them.\n\nUsed internally, `v1` and `v2` typically hold vertex ids, not the vertex itself, but all\npublic APIs which return `Graph.Edge` structs, return them with the actual vertices.","ref":"Graph.Edge.html"},{"type":"type","title":"Graph.Edge.edge_opt/0","doc":"","ref":"Graph.Edge.html#t:edge_opt/0"},{"type":"type","title":"Graph.Edge.edge_opts/0","doc":"","ref":"Graph.Edge.html#t:edge_opts/0"},{"type":"function","title":"Graph.Edge.new/3","doc":"Defines a new edge and accepts optional values for weight and label.\nThe defaults of a weight of 1 and no label will be used if the options do\nnot specify otherwise.\n\nAn error will be thrown if weight is not an integer or float.","ref":"Graph.Edge.html#new/3"},{"type":"function","title":"Example - Graph.Edge.new/3","doc":"iex> Graph.new |> Graph.add_edge(Graph.Edge.new(:a, :b, weight: \"1\"))\n    ** (ArgumentError) invalid value for :weight, must be an integer","ref":"Graph.Edge.html#new/3-example"},{"type":"type","title":"Graph.Edge.t/0","doc":"","ref":"Graph.Edge.html#t:t/0"},{"type":"module","title":"Graph.Pathfinding","doc":"This module contains implementation code for path finding algorithms used by `libgraph`.","ref":"Graph.Pathfinding.html"},{"type":"function","title":"Graph.Pathfinding.a_star/4","doc":"Finds the shortest path between `a` and `b` as a list of vertices.\nReturns `nil` if no path can be found.\n\nThis implementation takes a heuristic function which allows you to\ncalculate the lower bound cost of a given vertex `v`. The algorithm\nthen uses that lower bound function to determine which path to explore\nnext in the graph.\n\nThe `dijkstra` function is simply `a_star` where the heuristic function\nalways returns 0, and thus the next vertex is chosen based on the weight of\nthe edge between it and the current vertex.","ref":"Graph.Pathfinding.html#a_star/4"},{"type":"function","title":"Graph.Pathfinding.all/3","doc":"Finds all paths between `a` and `b`, each path as a list of vertices.\nReturns `nil` if no path can be found.","ref":"Graph.Pathfinding.html#all/3"},{"type":"function","title":"Graph.Pathfinding.bellman_ford/2","doc":"","ref":"Graph.Pathfinding.html#bellman_ford/2"},{"type":"function","title":"Graph.Pathfinding.dijkstra/3","doc":"Finds the shortest path between `a` and `b` as a list of vertices.\nReturns `nil` if no path can be found.\n\nThe shortest path is calculated here by using a cost function to choose\nwhich path to explore next. The cost function in Dijkstra's algorithm is\n`weight(E(A, B))+lower_bound(E(A, B))` where `lower_bound(E(A, B))` is always 0.","ref":"Graph.Pathfinding.html#dijkstra/3"},{"type":"type","title":"Graph.Pathfinding.heuristic_fun/0","doc":"","ref":"Graph.Pathfinding.html#t:heuristic_fun/0"},{"type":"module","title":"Graph.Pathfindings.BellmanFord","doc":"The Bellman–Ford algorithm is an algorithm that computes shortest paths from a single\nsource vertex to all of the other vertices in a weighted digraph.\nIt is capable of handling graphs in which some of the edge weights are negative numbers\nTime complexity: O(VLogV)","ref":"Graph.Pathfindings.BellmanFord.html"},{"type":"function","title":"Graph.Pathfindings.BellmanFord.call/2","doc":"Returns nil when graph has negative cycle.","ref":"Graph.Pathfindings.BellmanFord.html#call/2"},{"type":"behaviour","title":"Graph.Reducer","doc":"Reducers provide a way to traverse a graph while applying a function at each vertex. This\ncan be used for a variety of things, most notably though is pre-processing a graph, for example\none might decorate vertices with their distance from some known landmarks for later use in\na cost function for A*.\n\nThe `reduce` function takes a callback which has some control over when to terminate the traversal,\nto move to the next vertex, return `{:next, acc}`, but to stop traversal and return the accumulator,\nreturn `{:halt, acc}`. The `map` function is built on top of `reduce` but does not expose this control,\nso if you need to map over the graph but stop early, you'll want to build your own `map` implementation\non top of `reduce`.\n\nProvided out of the box are two reducers, `Graph.Reducers.Bfs` (for breadth-first traversals), and\n`Graph.Reducers.Dfs` (for depth-first traversals). Simply choose the best one for your use case.","ref":"Graph.Reducer.html"},{"type":"callback","title":"Graph.Reducer.map/2","doc":"","ref":"Graph.Reducer.html#c:map/2"},{"type":"callback","title":"Graph.Reducer.reduce/3","doc":"","ref":"Graph.Reducer.html#c:reduce/3"},{"type":"module","title":"Graph.Reducers.Bfs","doc":"This reducer traverses the graph using Breadth-First Search.","ref":"Graph.Reducers.Bfs.html"},{"type":"function","title":"Graph.Reducers.Bfs.map/2","doc":"Performs a breadth-first traversal of the graph, applying the provided mapping function to\neach new vertex encountered.\n\nNOTE: The algorithm will follow lower-weighted edges first.\n\nReturns a list of values returned from the mapper in the order they were encountered.","ref":"Graph.Reducers.Bfs.html#map/2"},{"type":"function","title":"Example - Graph.Reducers.Bfs.map/2","doc":"iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 3}])\n    ...> Elixir.Graph.Reducers.Bfs.map(g, fn v -> v end)\n    [1, 3, 4, 2]","ref":"Graph.Reducers.Bfs.html#map/2-example"},{"type":"function","title":"Graph.Reducers.Bfs.reduce/3","doc":"Performs a breadth-first traversal of the graph, applying the provided reducer function to\neach new vertex encountered and the accumulator.\n\nNOTE: The algorithm will follow lower-weighted edges first.\n\nThe result will be the state of the accumulator after the last reduction.","ref":"Graph.Reducers.Bfs.html#reduce/3"},{"type":"function","title":"Example - Graph.Reducers.Bfs.reduce/3","doc":"iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 3}])\n    ...> Elixir.Graph.Reducers.Bfs.reduce(g, [], fn v, acc -> {:next, [v|acc]} end)\n    [2, 4, 3, 1]\n\n    iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 3}, {4, 5}])\n    ...> Elixir.Graph.Reducers.Bfs.reduce(g, [], fn 5, acc -> {:skip, acc}; v, acc -> {:next, [v|acc]} end)\n    [2, 4, 3, 1]\n\n    iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 3}, {4, 5}])\n    ...> Elixir.Graph.Reducers.Bfs.reduce(g, [], fn 4, acc -> {:halt, acc}; v, acc -> {:next, [v|acc]} end)\n    [3, 1]","ref":"Graph.Reducers.Bfs.html#reduce/3-example"},{"type":"module","title":"Graph.Reducers.Dfs","doc":"This reducer traverses the graph using Depth-First Search.","ref":"Graph.Reducers.Dfs.html"},{"type":"function","title":"Graph.Reducers.Dfs.map/2","doc":"Performs a depth-first traversal of the graph, applying the provided mapping function to\neach new vertex encountered.\n\nNOTE: The algorithm will follow lower-weighted edges first.\n\nReturns a list of values returned from the mapper in the order they were encountered.","ref":"Graph.Reducers.Dfs.html#map/2"},{"type":"function","title":"Example - Graph.Reducers.Dfs.map/2","doc":"iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 4}])\n    ...> Elixir.Graph.Reducers.Dfs.map(g, fn v -> v end)\n    [1, 3, 2, 4]","ref":"Graph.Reducers.Dfs.html#map/2-example"},{"type":"function","title":"Graph.Reducers.Dfs.reduce/3","doc":"Performs a depth-first traversal of the graph, applying the provided reducer function to\neach new vertex encountered and the accumulator.\n\nNOTE: The algorithm will follow lower-weighted edges first.\n\nThe result will be the state of the accumulator after the last reduction.","ref":"Graph.Reducers.Dfs.html#reduce/3"},{"type":"function","title":"Example - Graph.Reducers.Dfs.reduce/3","doc":"iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 4}])\n    ...> Elixir.Graph.Reducers.Dfs.reduce(g, [], fn v, acc -> {:next, [v|acc]} end)\n    [4, 2, 3, 1]\n\n    iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4, 5])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 4}, {4, 5}])\n    ...> Elixir.Graph.Reducers.Dfs.reduce(g, [], fn 5, acc -> {:skip, acc}; v, acc -> {:next, [v|acc]} end)\n    [4, 2, 3, 1]\n\n    iex> g = Graph.new |> Graph.add_vertices([1, 2, 3, 4, 5])\n    ...> g = Graph.add_edges(g, [{1, 3}, {1, 4}, {3, 2}, {2, 4}, {4, 5}])\n    ...> Elixir.Graph.Reducers.Dfs.reduce(g, [], fn 4, acc -> {:halt, acc}; v, acc -> {:next, [v|acc]} end)\n    [2, 3, 1]","ref":"Graph.Reducers.Dfs.html#reduce/3-example"},{"type":"behaviour","title":"Graph.Serializer","doc":"This module defines the Serializer behavior for graphs.","ref":"Graph.Serializer.html"},{"type":"function","title":"Graph.Serializer.encode_label/1","doc":"","ref":"Graph.Serializer.html#encode_label/1"},{"type":"function","title":"Graph.Serializer.escape_quotes/1","doc":"","ref":"Graph.Serializer.html#escape_quotes/1"},{"type":"function","title":"Graph.Serializer.escape_quotes/2","doc":"","ref":"Graph.Serializer.html#escape_quotes/2"},{"type":"function","title":"Graph.Serializer.get_vertex_label/3","doc":"","ref":"Graph.Serializer.html#get_vertex_label/3"},{"type":"function","title":"Graph.Serializer.indent/1","doc":"","ref":"Graph.Serializer.html#indent/1"},{"type":"function","title":"Graph.Serializer.quoted/1","doc":"","ref":"Graph.Serializer.html#quoted/1"},{"type":"callback","title":"Graph.Serializer.serialize/1","doc":"","ref":"Graph.Serializer.html#c:serialize/1"},{"type":"module","title":"Graph.Serializers.DOT","doc":"This serializer converts a Graph to a DOT file, which can then be converted\nto a great many other formats using Graphviz, e.g. `dot -Tpng out.dot > out.png`.","ref":"Graph.Serializers.DOT.html"},{"type":"function","title":"Graph.Serializers.DOT.serialize/1","doc":"","ref":"Graph.Serializers.DOT.html#serialize/1"},{"type":"module","title":"Graph.Serializers.Edgelist","doc":"This serializer converts a `Graph` to an edgelist suitable for using with\ngraph libraries such as the polyglot igraph library.","ref":"Graph.Serializers.Edgelist.html"},{"type":"function","title":"Graph.Serializers.Edgelist.serialize/1","doc":"","ref":"Graph.Serializers.Edgelist.html#serialize/1"},{"type":"module","title":"Graph.Serializers.Flowchart","doc":"This serializer converts a `Graph` to a [Mermaid Flowchart](https://mermaid.js.org/syntax/flowchart.html).","ref":"Graph.Serializers.Flowchart.html"},{"type":"module","title":"Hologram","doc":"","ref":"Hologram.html"},{"type":"function","title":"Hologram.env/0","doc":"Returns the current environment.","ref":"Hologram.html#env/0"},{"type":"module","title":"Hologram.Application","doc":"","ref":"Hologram.Application.html"},{"type":"behaviour","title":"Hologram.Assets.ManifestCache","doc":"","ref":"Hologram.Assets.ManifestCache.html"},{"type":"function","title":"Hologram.Assets.ManifestCache.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hologram.Assets.ManifestCache.html#child_spec/1"},{"type":"function","title":"Hologram.Assets.ManifestCache.get_manifest_js/0","doc":"Returns JavaScript code that builds the asset manifest object.","ref":"Hologram.Assets.ManifestCache.html#get_manifest_js/0"},{"type":"function","title":"Hologram.Assets.ManifestCache.persistent_term_key/0","doc":"Returns the implementation of the asset manifest cache's persistent term key.","ref":"Hologram.Assets.ManifestCache.html#persistent_term_key/0"},{"type":"callback","title":"Hologram.Assets.ManifestCache.persistent_term_key/0","doc":"Returns the key of the persistent term used by the asset manifest cache registered process.","ref":"Hologram.Assets.ManifestCache.html#c:persistent_term_key/0"},{"type":"function","title":"Hologram.Assets.ManifestCache.reload/0","doc":"Reloads the the manifest cache data.","ref":"Hologram.Assets.ManifestCache.html#reload/0"},{"type":"function","title":"Hologram.Assets.ManifestCache.start_link/1","doc":"Starts asset manifest cache process.","ref":"Hologram.Assets.ManifestCache.html#start_link/1"},{"type":"behaviour","title":"Hologram.Assets.PageDigestRegistry","doc":"","ref":"Hologram.Assets.PageDigestRegistry.html"},{"type":"function","title":"Hologram.Assets.PageDigestRegistry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hologram.Assets.PageDigestRegistry.html#child_spec/1"},{"type":"function","title":"Hologram.Assets.PageDigestRegistry.dump_path/0","doc":"Returns the implementation of the page digest registry's dump path.","ref":"Hologram.Assets.PageDigestRegistry.html#dump_path/0"},{"type":"callback","title":"Hologram.Assets.PageDigestRegistry.dump_path/0","doc":"Returns the path of the dump file used by the page digest registry registered process.","ref":"Hologram.Assets.PageDigestRegistry.html#c:dump_path/0"},{"type":"function","title":"Hologram.Assets.PageDigestRegistry.ets_table_name/0","doc":"Returns the implementation of the page digest registry's ETS table name.","ref":"Hologram.Assets.PageDigestRegistry.html#ets_table_name/0"},{"type":"callback","title":"Hologram.Assets.PageDigestRegistry.ets_table_name/0","doc":"Returns the name of the ETS table used by the page digest registry registered process.","ref":"Hologram.Assets.PageDigestRegistry.html#c:ets_table_name/0"},{"type":"function","title":"Hologram.Assets.PageDigestRegistry.lookup/1","doc":"Returns the digest of the given page module.","ref":"Hologram.Assets.PageDigestRegistry.html#lookup/1"},{"type":"function","title":"Hologram.Assets.PageDigestRegistry.reload/0","doc":"Reloads the page digest registry data.","ref":"Hologram.Assets.PageDigestRegistry.html#reload/0"},{"type":"function","title":"Hologram.Assets.PageDigestRegistry.start_link/1","doc":"Starts page digest registry process.","ref":"Hologram.Assets.PageDigestRegistry.html#start_link/1"},{"type":"behaviour","title":"Hologram.Assets.PathRegistry","doc":"","ref":"Hologram.Assets.PathRegistry.html"},{"type":"function","title":"Hologram.Assets.PathRegistry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hologram.Assets.PathRegistry.html#child_spec/1"},{"type":"function","title":"Hologram.Assets.PathRegistry.ets_table_name/0","doc":"Returns the implementation of the asset path registry's ETS table name.","ref":"Hologram.Assets.PathRegistry.html#ets_table_name/0"},{"type":"callback","title":"Hologram.Assets.PathRegistry.ets_table_name/0","doc":"Returns the name of the ETS table used by the asset path registry registered process.","ref":"Hologram.Assets.PathRegistry.html#c:ets_table_name/0"},{"type":"function","title":"Hologram.Assets.PathRegistry.get_mapping/0","doc":"Returns the asset path mapping.","ref":"Hologram.Assets.PathRegistry.html#get_mapping/0"},{"type":"function","title":"Hologram.Assets.PathRegistry.handle_call/3","doc":"Returns the asset path mapping.","ref":"Hologram.Assets.PathRegistry.html#handle_call/3"},{"type":"function","title":"Hologram.Assets.PathRegistry.lookup/1","doc":"Looks up the asset path (that includes the digest) of the given static file located in static dir.\nIf there is no matching entry for the given static file then :error atom is returned.","ref":"Hologram.Assets.PathRegistry.html#lookup/1"},{"type":"function","title":"Hologram.Assets.PathRegistry.process_name/0","doc":"Returns the implementation of the asset path registry's process name.","ref":"Hologram.Assets.PathRegistry.html#process_name/0"},{"type":"callback","title":"Hologram.Assets.PathRegistry.process_name/0","doc":"Returns the process name registered for the the asset path registry.","ref":"Hologram.Assets.PathRegistry.html#c:process_name/0"},{"type":"function","title":"Hologram.Assets.PathRegistry.register/2","doc":"Registers the given asset path under the given static path key in the registry.","ref":"Hologram.Assets.PathRegistry.html#register/2"},{"type":"function","title":"Hologram.Assets.PathRegistry.reload/0","doc":"Reloads the path registry data.","ref":"Hologram.Assets.PathRegistry.html#reload/0"},{"type":"function","title":"Hologram.Assets.PathRegistry.start_link/1","doc":"Starts asset path registry process.","ref":"Hologram.Assets.PathRegistry.html#start_link/1"},{"type":"function","title":"Hologram.Assets.PathRegistry.static_dir/0","doc":"Returns the implementation of the asset path registry's static dir path.","ref":"Hologram.Assets.PathRegistry.html#static_dir/0"},{"type":"callback","title":"Hologram.Assets.PathRegistry.static_dir/0","doc":"Returns the path of the static dir used by the asset path registry registered process.","ref":"Hologram.Assets.PathRegistry.html#c:static_dir/0"},{"type":"module","title":"Hologram.Benchmarks","doc":"","ref":"Hologram.Benchmarks.html"},{"type":"function","title":"Hologram.Benchmarks.generate_module_digest_plts/3","doc":"Generates 2 module digest PLTs that fullfill the conditions given in the arguments.\n\nIf the arguments are floats they are treated as percentage (0.2 == 20%),\notherwise they are treated as (literal) number of modules.","ref":"Hologram.Benchmarks.html#generate_module_digest_plts/3"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout","doc":"","ref":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.__is_hologram_component__/0","doc":"Returns true to indicate that the callee module is a component module (has \"use Hologram.Component\" directive).","ref":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.html#__is_hologram_component__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Components.DefaultLayout.__is_hologram_component__/0","doc":"iex> __is_hologram_component__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.html#__is_hologram_component__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.__props__/0","doc":"Returns the list of property definitions for the compiled component.","ref":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.html#__props__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Components.DefaultLayout.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page1","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page1.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page1.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page1.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page1.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page1.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page1.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page1.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page1.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page1.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page10","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page10.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page10.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page10.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page10.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page10.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page10.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page10.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page10.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page10.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page100","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page100.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page100.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page100.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page100.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page100.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page100.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page100.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page100.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page100.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page11","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page11.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page11.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page11.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page11.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page11.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page11.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page11.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page11.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page11.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page12","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page12.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page12.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page12.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page12.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page12.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page12.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page12.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page12.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page12.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page13","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page13.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page13.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page13.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page13.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page13.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page13.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page13.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page13.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page13.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page14","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page14.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page14.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page14.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page14.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page14.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page14.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page14.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page14.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page14.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page15","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page15.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page15.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page15.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page15.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page15.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page15.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page15.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page15.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page15.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page16","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page16.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page16.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page16.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page16.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page16.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page16.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page16.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page16.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page16.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page17","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page17.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page17.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page17.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page17.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page17.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page17.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page17.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page17.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page17.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page18","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page18.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page18.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page18.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page18.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page18.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page18.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page18.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page18.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page18.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page19","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page19.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page19.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page19.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page19.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page19.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page19.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page19.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page19.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page19.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page2","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page2.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page2.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page2.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page2.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page2.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page2.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page2.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page2.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page2.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page20","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page20.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page20.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page20.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page20.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page20.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page20.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page20.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page20.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page20.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page21","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page21.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page21.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page21.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page21.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page21.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page21.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page21.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page21.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page21.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page22","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page22.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page22.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page22.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page22.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page22.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page22.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page22.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page22.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page22.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page23","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page23.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page23.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page23.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page23.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page23.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page23.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page23.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page23.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page23.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page24","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page24.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page24.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page24.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page24.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page24.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page24.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page24.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page24.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page24.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page25","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page25.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page25.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page25.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page25.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page25.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page25.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page25.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page25.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page25.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page26","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page26.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page26.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page26.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page26.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page26.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page26.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page26.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page26.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page26.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page27","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page27.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page27.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page27.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page27.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page27.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page27.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page27.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page27.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page27.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page28","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page28.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page28.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page28.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page28.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page28.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page28.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page28.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page28.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page28.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page29","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page29.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page29.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page29.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page29.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page29.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page29.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page29.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page29.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page29.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page3.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page3.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page3.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page3.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page3.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page3.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page3.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page3.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page3.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page30","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page30.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page30.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page30.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page30.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page30.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page30.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page30.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page30.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page30.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page31","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page31.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page31.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page31.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page31.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page31.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page31.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page31.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page31.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page31.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page32","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page32.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page32.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page32.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page32.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page32.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page32.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page32.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page32.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page32.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page33","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page33.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page33.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page33.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page33.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page33.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page33.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page33.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page33.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page33.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page34","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page34.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page34.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page34.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page34.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page34.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page34.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page34.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page34.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page34.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page35","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page35.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page35.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page35.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page35.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page35.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page35.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page35.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page35.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page35.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page36","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page36.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page36.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page36.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page36.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page36.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page36.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page36.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page36.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page36.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page37","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page37.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page37.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page37.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page37.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page37.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page37.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page37.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page37.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page37.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page38","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page38.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page38.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page38.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page38.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page38.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page38.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page38.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page38.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page38.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page39","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page39.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page39.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page39.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page39.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page39.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page39.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page39.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page39.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page39.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page4","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page4.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page4.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page4.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page4.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page4.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page4.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page4.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page4.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page4.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page40","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page40.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page40.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page40.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page40.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page40.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page40.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page40.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page40.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page40.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page41","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page41.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page41.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page41.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page41.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page41.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page41.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page41.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page41.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page41.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page42","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page42.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page42.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page42.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page42.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page42.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page42.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page42.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page42.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page42.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page43","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page43.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page43.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page43.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page43.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page43.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page43.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page43.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page43.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page43.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page44","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page44.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page44.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page44.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page44.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page44.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page44.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page44.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page44.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page44.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page45","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page45.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page45.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page45.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page45.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page45.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page45.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page45.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page45.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page45.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page46","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page46.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page46.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page46.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page46.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page46.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page46.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page46.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page46.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page46.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page47","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page47.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page47.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page47.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page47.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page47.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page47.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page47.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page47.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page47.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page48","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page48.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page48.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page48.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page48.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page48.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page48.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page48.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page48.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page48.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page49","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page49.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page49.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page49.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page49.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page49.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page49.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page49.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page49.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page49.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page5","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page5.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page5.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page5.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page5.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page5.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page5.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page5.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page5.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page5.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page50","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page50.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page50.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page50.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page50.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page50.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page50.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page50.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page50.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page50.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page51","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page51.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page51.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page51.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page51.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page51.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page51.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page51.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page51.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page51.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page52","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page52.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page52.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page52.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page52.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page52.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page52.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page52.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page52.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page52.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page53","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page53.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page53.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page53.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page53.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page53.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page53.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page53.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page53.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page53.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page54","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page54.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page54.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page54.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page54.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page54.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page54.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page54.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page54.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page54.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page55","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page55.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page55.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page55.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page55.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page55.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page55.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page55.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page55.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page55.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page56","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page56.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page56.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page56.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page56.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page56.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page56.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page56.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page56.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page56.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page57","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page57.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page57.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page57.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page57.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page57.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page57.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page57.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page57.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page57.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page58","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page58.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page58.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page58.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page58.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page58.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page58.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page58.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page58.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page58.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page59","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page59.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page59.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page59.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page59.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page59.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page59.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page59.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page59.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page59.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page6","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page6.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page6.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page6.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page6.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page6.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page6.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page6.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page6.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page6.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page60","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page60.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page60.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page60.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page60.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page60.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page60.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page60.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page60.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page60.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page61","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page61.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page61.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page61.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page61.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page61.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page61.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page61.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page61.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page61.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page62","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page62.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page62.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page62.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page62.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page62.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page62.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page62.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page62.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page62.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page63","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page63.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page63.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page63.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page63.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page63.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page63.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page63.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page63.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page63.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page64","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page64.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page64.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page64.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page64.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page64.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page64.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page64.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page64.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page64.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page65","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page65.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page65.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page65.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page65.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page65.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page65.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page65.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page65.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page65.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page66","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page66.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page66.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page66.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page66.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page66.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page66.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page66.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page66.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page66.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page67","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page67.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page67.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page67.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page67.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page67.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page67.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page67.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page67.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page67.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page68","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page68.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page68.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page68.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page68.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page68.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page68.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page68.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page68.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page68.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page69","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page69.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page69.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page69.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page69.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page69.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page69.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page69.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page69.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page69.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page7","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page7.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page7.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page7.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page7.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page7.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page7.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page7.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page7.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page7.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page70","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page70.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page70.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page70.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page70.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page70.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page70.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page70.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page70.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page70.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page71","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page71.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page71.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page71.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page71.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page71.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page71.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page71.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page71.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page71.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page72","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page72.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page72.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page72.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page72.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page72.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page72.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page72.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page72.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page72.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page73","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page73.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page73.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page73.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page73.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page73.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page73.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page73.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page73.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page73.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page74","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page74.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page74.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page74.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page74.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page74.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page74.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page74.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page74.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page74.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page75","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page75.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page75.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page75.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page75.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page75.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page75.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page75.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page75.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page75.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page76","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page76.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page76.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page76.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page76.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page76.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page76.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page76.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page76.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page76.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page77","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page77.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page77.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page77.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page77.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page77.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page77.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page77.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page77.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page77.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page78","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page78.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page78.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page78.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page78.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page78.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page78.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page78.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page78.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page78.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page79","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page79.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page79.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page79.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page79.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page79.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page79.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page79.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page79.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page79.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page8","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page8.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page8.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page8.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page8.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page8.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page8.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page8.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page8.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page8.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page80","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page80.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page80.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page80.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page80.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page80.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page80.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page80.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page80.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page80.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page81","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page81.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page81.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page81.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page81.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page81.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page81.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page81.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page81.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page81.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page82","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page82.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page82.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page82.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page82.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page82.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page82.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page82.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page82.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page82.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page83","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page83.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page83.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page83.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page83.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page83.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page83.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page83.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page83.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page83.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page84","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page84.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page84.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page84.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page84.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page84.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page84.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page84.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page84.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page84.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page85","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page85.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page85.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page85.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page85.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page85.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page85.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page85.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page85.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page85.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page86","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page86.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page86.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page86.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page86.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page86.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page86.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page86.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page86.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page86.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page87","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page87.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page87.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page87.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page87.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page87.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page87.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page87.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page87.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page87.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page88","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page88.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page88.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page88.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page88.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page88.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page88.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page88.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page88.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page88.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page89","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page89.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page89.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page89.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page89.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page89.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page89.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page89.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page89.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page89.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page9","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page9.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page9.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page9.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page9.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page9.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page9.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page9.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page9.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page9.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page90","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page90.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page90.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page90.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page90.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page90.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page90.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page90.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page90.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page90.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page91","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page91.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page91.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page91.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page91.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page91.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page91.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page91.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page91.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page91.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page92","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page92.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page92.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page92.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page92.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page92.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page92.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page92.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page92.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page92.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page93","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page93.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page93.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page93.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page93.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page93.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page93.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page93.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page93.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page93.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page94","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page94.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page94.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page94.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page94.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page94.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page94.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page94.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page94.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page94.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page95","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page95.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page95.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page95.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page95.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page95.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page95.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page95.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page95.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page95.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page96","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page96.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page96.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page96.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page96.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page96.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page96.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page96.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page96.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page96.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page97","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page97.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page97.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page97.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page97.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page97.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page97.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page97.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page97.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page97.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page98","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page98.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page98.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page98.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page98.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page98.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page98.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page98.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page98.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page98.html#template/0"},{"type":"module","title":"Hologram.Benchmarks.Fixtures.Page99","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page99.html"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.__is_hologram_page__/0","doc":"Returns true to indicate that the callee module is a page module (has \"use Hologram.Page\" directive).","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__is_hologram_page__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page99.__is_hologram_page__/0","doc":"iex> __is_hologram_page__()\n    true","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__is_hologram_page__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.__layout_module__/0","doc":"Returns the page's layout module.","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__layout_module__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page99.__layout_module__/0","doc":"iex> __layout_module__()\n    MyLayout","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__layout_module__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.__layout_props__/0","doc":"Returns the page's layout props.","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__layout_props__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page99.__layout_props__/0","doc":"iex> __layout_props__()\n    [a: 1, b: 2]","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__layout_props__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.__params__/0","doc":"Returns the list of param definitions for the compiled page.","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__params__/0"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.__route__/0","doc":"Returns the page's route.","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__route__/0"},{"type":"function","title":"Examples - Hologram.Benchmarks.Fixtures.Page99.__route__/0","doc":"iex> __route__()\n    \"/my-path\"","ref":"Hologram.Benchmarks.Fixtures.Page99.html#__route__/0-examples"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.action/3","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page99.html#action/3"},{"type":"function","title":"Hologram.Benchmarks.Fixtures.Page99.template/0","doc":"","ref":"Hologram.Benchmarks.Fixtures.Page99.html#template/0"},{"type":"module","title":"Hologram.Commons.AtomUtils","doc":"","ref":"Hologram.Commons.AtomUtils.html"},{"type":"function","title":"Hologram.Commons.AtomUtils.starts_with?/2","doc":"Returns `true` if `atom` starts with the given prefix.","ref":"Hologram.Commons.AtomUtils.html#starts_with?/2"},{"type":"module","title":"Hologram.Commons.BitstringUtils","doc":"","ref":"Hologram.Commons.BitstringUtils.html"},{"type":"function","title":"Hologram.Commons.BitstringUtils.from_bit_list/1","doc":"Converts a list of bits into a corresponding bitstring.","ref":"Hologram.Commons.BitstringUtils.html#from_bit_list/1"},{"type":"function","title":"Hologram.Commons.BitstringUtils.to_bit_list/1","doc":"Given a bitstring returns its corresponding list of bits (starting with the most significant bit at index 0).","ref":"Hologram.Commons.BitstringUtils.html#to_bit_list/1"},{"type":"function","title":"Examples - Hologram.Commons.BitstringUtils.to_bit_list/1","doc":"iex> to_bit_list(<<25>>)\n    [1, 1, 0, 0, 1]","ref":"Hologram.Commons.BitstringUtils.html#to_bit_list/1-examples"},{"type":"module","title":"Hologram.Commons.CryptographicUtils","doc":"","ref":"Hologram.Commons.CryptographicUtils.html"},{"type":"function","title":"Hologram.Commons.CryptographicUtils.digest/3","doc":"Calculates the cryptographic digest of the input data using the given algorithm (such as :md5, :sha256, etc.).\nOutput format can be either `:hex` (hexadecimal string) or `:binary` (binary data).","ref":"Hologram.Commons.CryptographicUtils.html#digest/3"},{"type":"function","title":"Examples - Hologram.Commons.CryptographicUtils.digest/3","doc":"iex> digest(\"Hologram\", :sha256, :hex)\n    \"ddff15a2da596882cfd545132004c8e7355e457517a3874f4853cc6ff1110c2e\"\n\n    iex> digest(\"Hologram\", false)\n    <<221, 255, 21, 162, 218, 89, 104, 130, 207, 213, 69, 19, 32, 4, 200, 231, 53,\n      94, 69, 117, 23, 163, 135, 79, 72, 83, 204, 111, 241, 17, 12, 46>>","ref":"Hologram.Commons.CryptographicUtils.html#digest/3-examples"},{"type":"module","title":"Hologram.Commons.ETS","doc":"","ref":"Hologram.Commons.ETS.html"},{"type":"function","title":"Hologram.Commons.ETS.create_named_table/1","doc":"Creates a named, public ETS table.","ref":"Hologram.Commons.ETS.html#create_named_table/1"},{"type":"function","title":"Hologram.Commons.ETS.create_unnamed_table/0","doc":"Creates an unnamed, public ETS table.","ref":"Hologram.Commons.ETS.html#create_unnamed_table/0"},{"type":"function","title":"Hologram.Commons.ETS.delete/1","doc":"Deletes the ETS table if it exists.","ref":"Hologram.Commons.ETS.html#delete/1"},{"type":"function","title":"Hologram.Commons.ETS.delete/2","doc":"Deletes a key-value pair from the ETS table.","ref":"Hologram.Commons.ETS.html#delete/2"},{"type":"function","title":"Hologram.Commons.ETS.delete!/1","doc":"Deletes the ETS table if it exists or raises ArgumentError otherwise.","ref":"Hologram.Commons.ETS.html#delete!/1"},{"type":"function","title":"Hologram.Commons.ETS.get/2","doc":"Returns the value stored in the ETS table under the given key.\nIf the key doesn't exist the :error :atom is returned.","ref":"Hologram.Commons.ETS.html#get/2"},{"type":"function","title":"Hologram.Commons.ETS.get!/2","doc":"Returns the value stored in the ETS table under the given key.\nIf the key doesn't exist a KeyError is raised.","ref":"Hologram.Commons.ETS.html#get!/2"},{"type":"function","title":"Hologram.Commons.ETS.get_all/1","doc":"Returns all items stored in the ETS table.","ref":"Hologram.Commons.ETS.html#get_all/1"},{"type":"function","title":"Hologram.Commons.ETS.put/2","doc":"Puts multiple items into the ETS table.","ref":"Hologram.Commons.ETS.html#put/2"},{"type":"function","title":"Hologram.Commons.ETS.put/3","doc":"Puts an item into the ETS table.","ref":"Hologram.Commons.ETS.html#put/3"},{"type":"function","title":"Hologram.Commons.ETS.reset/1","doc":"Removes all items from the ETS table.","ref":"Hologram.Commons.ETS.html#reset/1"},{"type":"function","title":"Hologram.Commons.ETS.table_exists?/1","doc":"Determines whether the given ETS table exists.","ref":"Hologram.Commons.ETS.html#table_exists?/1"},{"type":"type","title":"Hologram.Commons.ETS.tid/0","doc":"","ref":"Hologram.Commons.ETS.html#t:tid/0"},{"type":"module","title":"Hologram.Commons.FileUtils","doc":"","ref":"Hologram.Commons.FileUtils.html"},{"type":"function","title":"Hologram.Commons.FileUtils.list_files_recursively/1","doc":"Lists files nested in the given path or paths. The results are sorted in ascending order.\nThe result doesn't include directories.","ref":"Hologram.Commons.FileUtils.html#list_files_recursively/1"},{"type":"function","title":"Examples - Hologram.Commons.FileUtils.list_files_recursively/1","doc":"iex> list_files_recursively(\"test/elixir/fixtures/commons/file_utils/list_files_recursively/dir_1\")\n    [\"test/elixir/fixtures/commons/file_utils/list_files_recursively/dir_1/dir_3/file_5.txt\",\n     \"test/elixir/fixtures/commons/file_utils/list_files_recursively/dir_1/dir_3/file_6.txt\",\n     \"test/elixir/fixtures/commons/file_utils/list_files_recursively/dir_1/file_3.txt\",\n     \"test/elixir/fixtures/commons/file_utils/list_files_recursively/dir_1/file_4.txt\"]","ref":"Hologram.Commons.FileUtils.html#list_files_recursively/1-examples"},{"type":"function","title":"Hologram.Commons.FileUtils.recreate_dir/1","doc":"Removes the given dir (including all its contents) and creates an empty dir with the same name and path.","ref":"Hologram.Commons.FileUtils.html#recreate_dir/1"},{"type":"module","title":"Hologram.Commons.Guards","doc":"","ref":"Hologram.Commons.Guards.html"},{"type":"macro","title":"Hologram.Commons.Guards.is_regex/1","doc":"","ref":"Hologram.Commons.Guards.html#is_regex/1"},{"type":"module","title":"Hologram.Commons.IntegerUtils","doc":"","ref":"Hologram.Commons.IntegerUtils.html"},{"type":"function","title":"Hologram.Commons.IntegerUtils.count_digits/1","doc":"Counts the number of digits in the given integer.","ref":"Hologram.Commons.IntegerUtils.html#count_digits/1"},{"type":"function","title":"Examples - Hologram.Commons.IntegerUtils.count_digits/1","doc":"iex> count_digits(123)\n    3\n\n    iex> count_digits(0)\n    1\n\n    iex> count_digits(-123)\n    3","ref":"Hologram.Commons.IntegerUtils.html#count_digits/1-examples"},{"type":"function","title":"Hologram.Commons.IntegerUtils.ordinal/1","doc":"Returns the ordinal number (number with suffix \"st\", \"nd\", \"rd\", or \"th\") for a given integer.","ref":"Hologram.Commons.IntegerUtils.html#ordinal/1"},{"type":"function","title":"Examples - Hologram.Commons.IntegerUtils.ordinal/1","doc":"iex> ordinal(1)\n    \"1st\"\n    \n    iex> ordinal(42)\n    \"42nd\"\n    \n    iex> ordinal(11)\n    \"11th\"","ref":"Hologram.Commons.IntegerUtils.html#ordinal/1-examples"},{"type":"function","title":"Hologram.Commons.IntegerUtils.parse!/2","doc":"Parses a text representation of an integer.\n\nRaises an error if the text representation can't be parsed,\nor if the base is less than 2 or more than 36,\nor if only part of the text representation can be parsed.","ref":"Hologram.Commons.IntegerUtils.html#parse!/2"},{"type":"module","title":"Hologram.Commons.KernelUtils","doc":"","ref":"Hologram.Commons.KernelUtils.html"},{"type":"function","title":"Hologram.Commons.KernelUtils.inspect/1","doc":"Inspects the given argument according to the Inspect protocol.\nMaps inspection is deterministic by sorting their key-value pairs.","ref":"Hologram.Commons.KernelUtils.html#inspect/1"},{"type":"module","title":"Hologram.Commons.PLT","doc":"Provides a persistent lookup table (PLT) implemented using ETS (Erlang Term Storage) and GenServer.\nIt allows to store key-value pairs in memory and perform various operations on the data.\nThe data in memory can be dumped to a file and loaded from a file.","ref":"Hologram.Commons.PLT.html"},{"type":"function","title":"Hologram.Commons.PLT.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hologram.Commons.PLT.html#child_spec/1"},{"type":"function","title":"Hologram.Commons.PLT.clone/1","doc":"Returns a clone of the PLT.","ref":"Hologram.Commons.PLT.html#clone/1"},{"type":"function","title":"Hologram.Commons.PLT.delete/2","doc":"Deletes a key-value pair from the PLT.","ref":"Hologram.Commons.PLT.html#delete/2"},{"type":"function","title":"Hologram.Commons.PLT.dump/2","doc":"Serializes the contents of the PLT and writes it to a file.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/commons/plt/dump_2/README.md","ref":"Hologram.Commons.PLT.html#dump/2"},{"type":"function","title":"Hologram.Commons.PLT.get/2","doc":"Returns the value stored in the PLT under the given key.\nIf the key doesn't exist the :error :atom is returned.","ref":"Hologram.Commons.PLT.html#get/2"},{"type":"function","title":"Hologram.Commons.PLT.get!/2","doc":"Returns the value stored in the PLT under the given key.\nIf the key doesn't exist a KeyError is raised.","ref":"Hologram.Commons.PLT.html#get!/2"},{"type":"function","title":"Hologram.Commons.PLT.get_all/1","doc":"Returns all items stored in the PLT.","ref":"Hologram.Commons.PLT.html#get_all/1"},{"type":"function","title":"Hologram.Commons.PLT.handle_call/3","doc":"Returns the reference of the underlying ETS table.","ref":"Hologram.Commons.PLT.html#handle_call/3"},{"type":"function","title":"Hologram.Commons.PLT.init/1","doc":"Creates the underlying ETS table.","ref":"Hologram.Commons.PLT.html#init/1"},{"type":"function","title":"Hologram.Commons.PLT.load/2","doc":"Populates the PLT with items dumped to the given file.","ref":"Hologram.Commons.PLT.html#load/2"},{"type":"function","title":"Hologram.Commons.PLT.maybe_load/2","doc":"Populates the PLT with items dumped to the given file if the file exists.","ref":"Hologram.Commons.PLT.html#maybe_load/2"},{"type":"function","title":"Hologram.Commons.PLT.put/2","doc":"Puts multiple items into the PLT.","ref":"Hologram.Commons.PLT.html#put/2"},{"type":"function","title":"Hologram.Commons.PLT.put/3","doc":"Puts the given item into the PLT.","ref":"Hologram.Commons.PLT.html#put/3"},{"type":"function","title":"Hologram.Commons.PLT.reset/1","doc":"Removes all items from the PLT.","ref":"Hologram.Commons.PLT.html#reset/1"},{"type":"function","title":"Hologram.Commons.PLT.size/1","doc":"Returns the number of items in the PLT.","ref":"Hologram.Commons.PLT.html#size/1"},{"type":"function","title":"Hologram.Commons.PLT.start/1","doc":"Starts the underlying GenServer process.","ref":"Hologram.Commons.PLT.html#start/1"},{"type":"function","title":"Hologram.Commons.PLT.stop/1","doc":"Stops the underlying GenServer process.","ref":"Hologram.Commons.PLT.html#stop/1"},{"type":"type","title":"Hologram.Commons.PLT.t/0","doc":"","ref":"Hologram.Commons.PLT.html#t:t/0"},{"type":"module","title":"Hologram.Commons.ProcessUtils","doc":"","ref":"Hologram.Commons.ProcessUtils.html"},{"type":"function","title":"Hologram.Commons.ProcessUtils.running?/1","doc":"Tells whether the process with the given name is running.","ref":"Hologram.Commons.ProcessUtils.html#running?/1"},{"type":"module","title":"Hologram.Commons.SerializationUtils","doc":"","ref":"Hologram.Commons.SerializationUtils.html"},{"type":"function","title":"Hologram.Commons.SerializationUtils.deserialize/2","doc":"Deserializes binary data to Elixir term.","ref":"Hologram.Commons.SerializationUtils.html#deserialize/2"},{"type":"function","title":"Examples - Hologram.Commons.SerializationUtils.deserialize/2","doc":"iex> deserialize(<<131, 104, 3, 97, 1, 97, 2, 97, 3>>)\n    {1, 2, 3}","ref":"Hologram.Commons.SerializationUtils.html#deserialize/2-examples"},{"type":"function","title":"Hologram.Commons.SerializationUtils.serialize/1","doc":"Serializes Elixir term to binary data.","ref":"Hologram.Commons.SerializationUtils.html#serialize/1"},{"type":"function","title":"Examples - Hologram.Commons.SerializationUtils.serialize/1","doc":"iex> serialize({1, 2, 3})\n    <<131, 104, 3, 97, 1, 97, 2, 97, 3>>","ref":"Hologram.Commons.SerializationUtils.html#serialize/1-examples"},{"type":"module","title":"Hologram.Commons.StringUtils","doc":"","ref":"Hologram.Commons.StringUtils.html"},{"type":"function","title":"Hologram.Commons.StringUtils.prepend/2","doc":"Prepends the prefix to the given string.","ref":"Hologram.Commons.StringUtils.html#prepend/2"},{"type":"function","title":"Examples - Hologram.Commons.StringUtils.prepend/2","doc":"iex> prepend(\"abc\", \"xyz\")\n    \"xyzabc\"","ref":"Hologram.Commons.StringUtils.html#prepend/2-examples"},{"type":"function","title":"Hologram.Commons.StringUtils.prepend_if_not_empty/2","doc":"Prepends the prefix to the given string if the string is not empty.","ref":"Hologram.Commons.StringUtils.html#prepend_if_not_empty/2"},{"type":"function","title":"Examples - Hologram.Commons.StringUtils.prepend_if_not_empty/2","doc":"iex> prepend_if_not_empty(\"abc\", \"xyz\")\n    \"xyzabc\"\n    \n    iex> prepend_if_not_empty(\"\", \"xyz\")\n    \"\"","ref":"Hologram.Commons.StringUtils.html#prepend_if_not_empty/2-examples"},{"type":"function","title":"Hologram.Commons.StringUtils.starts_with_lowercase?/1","doc":"Checks whether a string starts with a lowercase letter.\n\n- This function uses the `String.next_grapheme/1` function to extract the first letter of the string.\n- It converts the first letter to lowercase using `String.downcase/1` and compares it with the original first letter to determine if it is lowercase.\n- If the input string is empty, the function returns `false`.","ref":"Hologram.Commons.StringUtils.html#starts_with_lowercase?/1"},{"type":"function","title":"Parameters - Hologram.Commons.StringUtils.starts_with_lowercase?/1","doc":"- `str` - The input string to be checked.","ref":"Hologram.Commons.StringUtils.html#starts_with_lowercase?/1-parameters"},{"type":"function","title":"Returns - Hologram.Commons.StringUtils.starts_with_lowercase?/1","doc":"Returns `true` if the string starts with a lowercase letter, and `false` otherwise.","ref":"Hologram.Commons.StringUtils.html#starts_with_lowercase?/1-returns"},{"type":"function","title":"Examples - Hologram.Commons.StringUtils.starts_with_lowercase?/1","doc":"iex> starts_with_lowercase?(\"Hello\")\n    false\n\n    iex> starts_with_lowercase?(\"world\")\n    true","ref":"Hologram.Commons.StringUtils.html#starts_with_lowercase?/1-examples"},{"type":"function","title":"Hologram.Commons.StringUtils.wrap/3","doc":"Wraps the given string with one string on the left side and another string on the right side.","ref":"Hologram.Commons.StringUtils.html#wrap/3"},{"type":"function","title":"Examples - Hologram.Commons.StringUtils.wrap/3","doc":"iex> wrap(\"ab\", \"cd\", \"ef\")\n    \"cdabef\"","ref":"Hologram.Commons.StringUtils.html#wrap/3-examples"},{"type":"module","title":"Hologram.Commons.SystemUtils","doc":"","ref":"Hologram.Commons.SystemUtils.html"},{"type":"function","title":"Hologram.Commons.SystemUtils.otp_version/0","doc":"Returns the OTP major version.","ref":"Hologram.Commons.SystemUtils.html#otp_version/0"},{"type":"module","title":"Hologram.Commons.TaskUtils","doc":"","ref":"Hologram.Commons.TaskUtils.html"},{"type":"function","title":"Hologram.Commons.TaskUtils.async_many/2","doc":"Starts multiple tasks.","ref":"Hologram.Commons.TaskUtils.html#async_many/2"},{"type":"module","title":"Hologram.Commons.TestUtils","doc":"","ref":"Hologram.Commons.TestUtils.html"},{"type":"function","title":"Hologram.Commons.TestUtils.build_argument_error_msg/2","doc":"Builds an error message for ArgumentError.","ref":"Hologram.Commons.TestUtils.html#build_argument_error_msg/2"},{"type":"function","title":"Hologram.Commons.TestUtils.build_function_clause_error_msg/3","doc":"Builds an error message for FunctionClauseError.","ref":"Hologram.Commons.TestUtils.html#build_function_clause_error_msg/3"},{"type":"function","title":"Hologram.Commons.TestUtils.build_undefined_function_error/3","doc":"Builds an error message for UndefinedFunctionError.","ref":"Hologram.Commons.TestUtils.html#build_undefined_function_error/3"},{"type":"function","title":"Hologram.Commons.TestUtils.pid/1","doc":"","ref":"Hologram.Commons.TestUtils.html#pid/1"},{"type":"function","title":"Hologram.Commons.TestUtils.port/1","doc":"","ref":"Hologram.Commons.TestUtils.html#port/1"},{"type":"function","title":"Hologram.Commons.TestUtils.ref/1","doc":"","ref":"Hologram.Commons.TestUtils.html#ref/1"},{"type":"function","title":"Hologram.Commons.TestUtils.wrap_term/1","doc":"Returns the given argument.\nIt prevents compiler warnings in tests when the given value is not permitted is specific situation.","ref":"Hologram.Commons.TestUtils.html#wrap_term/1"},{"type":"module","title":"Hologram.Commons.Types","doc":"","ref":"Hologram.Commons.Types.html"},{"type":"type","title":"Hologram.Commons.Types.alias_segments/0","doc":"","ref":"Hologram.Commons.Types.html#t:alias_segments/0"},{"type":"type","title":"Hologram.Commons.Types.file_path/0","doc":"","ref":"Hologram.Commons.Types.html#t:file_path/0"},{"type":"type","title":"Hologram.Commons.Types.opts/0","doc":"","ref":"Hologram.Commons.Types.html#t:opts/0"},{"type":"module","title":"Hologram.Compiler","doc":"","ref":"Hologram.Compiler.html"},{"type":"function","title":"Hologram.Compiler.build_call_graph/0","doc":"Builds the call graph of all modules in the project.","ref":"Hologram.Compiler.html#build_call_graph/0"},{"type":"function","title":"Hologram.Compiler.build_call_graph/1","doc":"Builds the call graph of all modules in the given IR PLT.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/build_call_graph_1/README.md","ref":"Hologram.Compiler.html#build_call_graph/1"},{"type":"function","title":"Hologram.Compiler.build_ir_plt/0","doc":"Builds IR persistent lookup table (PLT) of all modules in the project.","ref":"Hologram.Compiler.html#build_ir_plt/0"},{"type":"function","title":"Hologram.Compiler.build_ir_plt/1","doc":"Builds IR persistent lookup table (PLT) of all modules in the project using the given module BEAM path PLT.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/build_ir_plt_1/README.md","ref":"Hologram.Compiler.html#build_ir_plt/1"},{"type":"function","title":"Hologram.Compiler.build_module_beam_path_plt/0","doc":"Builds module BEAM path persistent lookup table (PLT) of all modules in the project.","ref":"Hologram.Compiler.html#build_module_beam_path_plt/0"},{"type":"function","title":"Hologram.Compiler.build_module_digest_plt!/1","doc":"Builds a persistent lookup table (PLT) containing the BEAM defs digests for all the modules in the project.\nMutates module BEAM path PLT.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/build_module_digest_plt!_1/README.md","ref":"Hologram.Compiler.html#build_module_digest_plt!/1"},{"type":"function","title":"Hologram.Compiler.build_page_digest_plt/2","doc":"Builds page digest PLT, where the keys represent page modules,\nand the values are hex digests of their corresponding JavaScript bundles.","ref":"Hologram.Compiler.html#build_page_digest_plt/2"},{"type":"function","title":"Hologram.Compiler.build_page_js/4","doc":"Builds JavaScript code for the given Hologram page.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/build_page_js_4/README.md","ref":"Hologram.Compiler.html#build_page_js/4"},{"type":"function","title":"Hologram.Compiler.build_runtime_js/3","doc":"Builds Hologram runtime JavaScript source code.","ref":"Hologram.Compiler.html#build_runtime_js/3"},{"type":"function","title":"Hologram.Compiler.bundle/2","doc":"Bundles multiple entry files.\nIncludes the source maps of the output files.\nThe output files' and source maps' file names contain hex digest.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/bundle_2/README.md","ref":"Hologram.Compiler.html#bundle/2"},{"type":"function","title":"Hologram.Compiler.bundle/4","doc":"Bundles the given entry file.\nIncludes the source map of the output file.\nThe output file and source map file names contain hex digest.","ref":"Hologram.Compiler.html#bundle/4"},{"type":"function","title":"Hologram.Compiler.create_page_entry_files/4","doc":"Creates page bundle entry file.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/create_page_entry_files_4/README.md","ref":"Hologram.Compiler.html#create_page_entry_files/4"},{"type":"function","title":"Hologram.Compiler.create_runtime_entry_file/3","doc":"Creates runtime bundle entry file.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/create_runtime_entry_file_3/README.md","ref":"Hologram.Compiler.html#create_runtime_entry_file/3"},{"type":"function","title":"Hologram.Compiler.diff_module_digest_plts/2","doc":"Compares two module digest PLTs and returns the added, removed, and updated modules lists.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/diff_module_digest_plts_2/README.md","ref":"Hologram.Compiler.html#diff_module_digest_plts/2"},{"type":"function","title":"Hologram.Compiler.format_files/2","doc":"Formats the given JavaScript files with Biome.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/format_files_2/README.md","ref":"Hologram.Compiler.html#format_files/2"},{"type":"function","title":"Hologram.Compiler.group_mfas_by_module/1","doc":"Groups the given MFAs by module.","ref":"Hologram.Compiler.html#group_mfas_by_module/1"},{"type":"function","title":"Hologram.Compiler.install_js_deps/2","doc":"Installs JavaScript deps which are specified in package.json located in assets_dir.\nSaves the package.json digest to package_json_digest.bin file in build_dir.","ref":"Hologram.Compiler.html#install_js_deps/2"},{"type":"function","title":"Hologram.Compiler.maybe_install_js_deps/2","doc":"Installs JavaScript deps if package.json has changed or if the deps haven't been installed yet.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/maybe_install_js_deps_2/README.md","ref":"Hologram.Compiler.html#maybe_install_js_deps/2"},{"type":"function","title":"Hologram.Compiler.maybe_load_call_graph/1","doc":"Loads call graph from a dump file if the file exists or creates an empty call graph.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/maybe_load_call_graph_1/README.md","ref":"Hologram.Compiler.html#maybe_load_call_graph/1"},{"type":"function","title":"Hologram.Compiler.maybe_load_ir_plt/1","doc":"Loads IR PLT from a dump file if the file exists or creates an empty PLT.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/maybe_load_ir_plt_1/README.md","ref":"Hologram.Compiler.html#maybe_load_ir_plt/1"},{"type":"function","title":"Hologram.Compiler.maybe_load_module_beam_path_plt/1","doc":"Loads module BEAM path PLT from a dump file if the file exists or creates an empty PLT.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/maybe_load_module_beam_path_plt_1/README.md","ref":"Hologram.Compiler.html#maybe_load_module_beam_path_plt/1"},{"type":"function","title":"Hologram.Compiler.maybe_load_module_digest_plt/1","doc":"Loads module digest PLT from a dump file if the file exists or creates an empty PLT.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/maybe_load_module_digest_plt_1/README.md","ref":"Hologram.Compiler.html#maybe_load_module_digest_plt/1"},{"type":"function","title":"Hologram.Compiler.patch_ir_plt!/3","doc":"Given a module digests diff, updates the IR persistent lookup table (PLT)\nby deleting entries for modules that have been removed,\nrebuilding the IR of modules that have been updated,\nand adding the IR of new modules.","ref":"Hologram.Compiler.html#patch_ir_plt!/3"},{"type":"function","title":"Hologram.Compiler.prune_module_def/2","doc":"Keeps only those IR expressions that are function definitions of the given reachable MFAs.","ref":"Hologram.Compiler.html#prune_module_def/2"},{"type":"function","title":"Hologram.Compiler.validate_page_modules/1","doc":"Raises a compilation error if any page module lacks a specified route or layout.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/validate_page_modules_1/README.md","ref":"Hologram.Compiler.html#validate_page_modules/1"},{"type":"module","title":"Hologram.Compiler.AST","doc":"","ref":"Hologram.Compiler.AST.html"},{"type":"function","title":"Hologram.Compiler.AST.for_code/1","doc":"Given Elixir source code returns its normalized Elixir AST.","ref":"Hologram.Compiler.AST.html#for_code/1"},{"type":"function","title":"Examples - Hologram.Compiler.AST.for_code/1","doc":"iex> for_code(\"1 + 2\")\n    {:+, [line: 1], [1, 2]}","ref":"Hologram.Compiler.AST.html#for_code/1-examples"},{"type":"function","title":"Hologram.Compiler.AST.for_module/2","doc":"Returns normalized AST of the given module.\nSpecifying the module's BEAM path makes the call faster.","ref":"Hologram.Compiler.AST.html#for_module/2"},{"type":"type","title":"Hologram.Compiler.AST.t/0","doc":"","ref":"Hologram.Compiler.AST.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.CallGraph","doc":"","ref":"Hologram.Compiler.CallGraph.html"},{"type":"function","title":"Hologram.Compiler.CallGraph.add_edge/3","doc":"Adds an edge between two vertices in the call graph.","ref":"Hologram.Compiler.CallGraph.html#add_edge/3"},{"type":"function","title":"Hologram.Compiler.CallGraph.add_edges/2","doc":"Adds multiple edges to the call graph.","ref":"Hologram.Compiler.CallGraph.html#add_edges/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.add_vertex/2","doc":"Adds the vertex to the call graph.","ref":"Hologram.Compiler.CallGraph.html#add_vertex/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.build/3","doc":"Builds a call graph from IR.","ref":"Hologram.Compiler.CallGraph.html#build/3"},{"type":"function","title":"Hologram.Compiler.CallGraph.build_for_module/3","doc":"Builds a call graph from a module definition IR located in the given IR PLT.","ref":"Hologram.Compiler.CallGraph.html#build_for_module/3"},{"type":"function","title":"Hologram.Compiler.CallGraph.clone/1","doc":"Returns a clone of the given call graph.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/clone_1/README.md","ref":"Hologram.Compiler.CallGraph.html#clone/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.dump/2","doc":"Serializes the call graph and writes it to a file.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/dump_2/README.md","ref":"Hologram.Compiler.CallGraph.html#dump/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.edges/1","doc":"Returns graph edges.","ref":"Hologram.Compiler.CallGraph.html#edges/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.get_graph/1","doc":"Returns the underlying libgraph %Graph{} struct containing vertices and edges data.","ref":"Hologram.Compiler.CallGraph.html#get_graph/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.has_edge?/3","doc":"Checks if an edge exists between two given vertices in the call graph.","ref":"Hologram.Compiler.CallGraph.html#has_edge?/3"},{"type":"function","title":"Hologram.Compiler.CallGraph.has_vertex?/2","doc":"Checks if the given vertex exists in the call graph.","ref":"Hologram.Compiler.CallGraph.html#has_vertex?/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.inbound_remote_edges/2","doc":"Returns the edges in which the second vertex is either the given module or a function from the given module,\nand the first vertex is a function from a different module.","ref":"Hologram.Compiler.CallGraph.html#inbound_remote_edges/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.list_page_entry_mfas/1","doc":"Lists the entry MFAs {module, function, arity} for a given page module.\n\nThis function returns a list of MFAs that are considered entry points for a page,\nincluding functions from both the page module and its associated layout module.","ref":"Hologram.Compiler.CallGraph.html#list_page_entry_mfas/1"},{"type":"function","title":"Parameters - Hologram.Compiler.CallGraph.list_page_entry_mfas/1","doc":"* `page_module` - The module of the page for which to list entry MFAs.","ref":"Hologram.Compiler.CallGraph.html#list_page_entry_mfas/1-parameters"},{"type":"function","title":"Returns - Hologram.Compiler.CallGraph.list_page_entry_mfas/1","doc":"A list of MFAs (tuples of {module, function, arity}) that serve as entry points\nfor the given page module and its layout.","ref":"Hologram.Compiler.CallGraph.html#list_page_entry_mfas/1-returns"},{"type":"function","title":"Hologram.Compiler.CallGraph.list_page_mfas/2","doc":"Returns the list of MFAs that are reachable by the given page.","ref":"Hologram.Compiler.CallGraph.html#list_page_mfas/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.list_runtime_entry_mfas/0","doc":"Lists entry runtime MFAs, which include MFAs used by the client runtime JS classes\nand client MFAs used by all pages and components.\nThe returned MFAs are sorted.","ref":"Hologram.Compiler.CallGraph.html#list_runtime_entry_mfas/0"},{"type":"function","title":"Hologram.Compiler.CallGraph.list_runtime_mfas/1","doc":"Lists MFAs required by the runtime JS script.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/list_runtime_mfas_1/README.md","ref":"Hologram.Compiler.CallGraph.html#list_runtime_mfas/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.load/2","doc":"Loads the graph from the given dump file.","ref":"Hologram.Compiler.CallGraph.html#load/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.maybe_load/2","doc":"Loads the graph from the given dump file if the file exists.","ref":"Hologram.Compiler.CallGraph.html#maybe_load/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.module_vertices/2","doc":"Returns the list of vertices that are MFAs belonging to the given module.","ref":"Hologram.Compiler.CallGraph.html#module_vertices/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.patch/3","doc":"Given a diff of changes, updates the call graph\nby deleting the graph paths of modules that have been removed,\nrebuilding the graph paths of modules that have been updated,\nand adding the graph paths of modules that have been added.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/patch_3/README.md","ref":"Hologram.Compiler.CallGraph.html#patch/3"},{"type":"function","title":"Hologram.Compiler.CallGraph.put_graph/2","doc":"Replace the state of underlying Agent process with the given graph.","ref":"Hologram.Compiler.CallGraph.html#put_graph/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.reachable/2","doc":"Lists vertices that are reachable from the given graph vertex or vertices.","ref":"Hologram.Compiler.CallGraph.html#reachable/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.remove_manually_ported_mfas/1","doc":"Removes call graph vertices for Elixir functions ported manually.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/remove_manually_ported_mfas_1/README.md","ref":"Hologram.Compiler.CallGraph.html#remove_manually_ported_mfas/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.remove_runtime_mfas!/2","doc":"Removes call graph vertices and edges related to MFAs used by the runtime.\n\nremove_vertices/2 is very slow on large graphs -\nfor a base case it would take over 7 seconds to remove runtime MFAs that way.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/remove_runtime_mfas!_2/README.md","ref":"Hologram.Compiler.CallGraph.html#remove_runtime_mfas!/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.remove_vertex/2","doc":"Removes the vertex from the call graph.","ref":"Hologram.Compiler.CallGraph.html#remove_vertex/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.remove_vertices/2","doc":"Removes the vertices from the call graph.\n\nBenchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/compiler/call_graph/remove_vertices_2/README.md","ref":"Hologram.Compiler.CallGraph.html#remove_vertices/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.sorted_edges/1","doc":"Returns sorted graph edges.","ref":"Hologram.Compiler.CallGraph.html#sorted_edges/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.sorted_reachable_mfas/2","doc":"Lists MFAs that are reachable from the given call graph vertex or vertices.\nUnimplemented protocol implentations are excluded.\nThe MFAs returned are sorted.","ref":"Hologram.Compiler.CallGraph.html#sorted_reachable_mfas/2"},{"type":"function","title":"Hologram.Compiler.CallGraph.sorted_vertices/1","doc":"Returns sorted graph vertices.","ref":"Hologram.Compiler.CallGraph.html#sorted_vertices/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.start/1","doc":"Starts a new CallGraph agent with (optional) initial graph.","ref":"Hologram.Compiler.CallGraph.html#start/1"},{"type":"function","title":"Hologram.Compiler.CallGraph.stop/1","doc":"Stops the CallGraph agent.","ref":"Hologram.Compiler.CallGraph.html#stop/1"},{"type":"type","title":"Hologram.Compiler.CallGraph.t/0","doc":"","ref":"Hologram.Compiler.CallGraph.html#t:t/0"},{"type":"type","title":"Hologram.Compiler.CallGraph.vertex/0","doc":"","ref":"Hologram.Compiler.CallGraph.html#t:vertex/0"},{"type":"function","title":"Hologram.Compiler.CallGraph.vertices/1","doc":"Returns graph vertices.","ref":"Hologram.Compiler.CallGraph.html#vertices/1"},{"type":"module","title":"Hologram.Compiler.Context","doc":"","ref":"Hologram.Compiler.Context.html"},{"type":"type","title":"Hologram.Compiler.Context.t/0","doc":"","ref":"Hologram.Compiler.Context.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.Encoder","doc":"","ref":"Hologram.Compiler.Encoder.html"},{"type":"function","title":"Hologram.Compiler.Encoder.debug/3","doc":"Prints debug info for intercepted encode_ir/2 calls.","ref":"Hologram.Compiler.Encoder.html#debug/3"},{"type":"function","title":"Hologram.Compiler.Encoder.encode_as_class_name/1","doc":"Encodes Elixir or Erlang alias as JavaScript class name.","ref":"Hologram.Compiler.Encoder.html#encode_as_class_name/1"},{"type":"function","title":"Examples - Hologram.Compiler.Encoder.encode_as_class_name/1","doc":"iex> encode_as_class_name(Aaa.Bbb.Ccc)\n    \"Elixir_Aaa_Bbb_Ccc\"\n\n    iex> encode_as_class_name(:erlang)\n    \"Erlang\"\n    \n    iex> encode_as_class_name(:aaa_bbb)\n    \"Erlang_Aaa_Bbb\"","ref":"Hologram.Compiler.Encoder.html#encode_as_class_name/1-examples"},{"type":"function","title":"Hologram.Compiler.Encoder.encode_elixir_function/6","doc":"Encodes an Elixir function into a JavaScript statement.","ref":"Hologram.Compiler.Encoder.html#encode_elixir_function/6"},{"type":"function","title":"Hologram.Compiler.Encoder.encode_erlang_function/4","doc":"Extracts JavaScript source code for the given ported Erlang function and generates interpreter function definition JavaScript statetement.","ref":"Hologram.Compiler.Encoder.html#encode_erlang_function/4"},{"type":"function","title":"Hologram.Compiler.Encoder.encode_ir/2","doc":"Encodes Elixir IR to JavaScript source code.","ref":"Hologram.Compiler.Encoder.html#encode_ir/2"},{"type":"function","title":"Examples - Hologram.Compiler.Encoder.encode_ir/2","doc":"iex> ir = %IR.ListType{\n    ...>   data: [\n    ...>     %IR.IntegerType{value: 1},\n    ...>     %IR.AtomType{value: :abc}\n    ...>   ]\n    ...> }\n    iex> encode_ir(ir, %Context{})\n    \"Type.list([Type.integer(1), Type.atom(\"abc\")])\"","ref":"Hologram.Compiler.Encoder.html#encode_ir/2-examples"},{"type":"function","title":"Hologram.Compiler.Encoder.encode_term/1","doc":"Encodes Elixir term into JavaScript.\nIf the term can be encoded into JavaScript then the result is in the shape of {:ok, js}.\nIf the term can't be encoded into JavaScript then an error message is returned in the shape of {:error, message}.","ref":"Hologram.Compiler.Encoder.html#encode_term/1"},{"type":"function","title":"Hologram.Compiler.Encoder.encode_term!/1","doc":"Encodes Elixir term into JavaScript, erroring out if the term can't be encoded into JavaScript.","ref":"Hologram.Compiler.Encoder.html#encode_term!/1"},{"type":"module","title":"Hologram.Compiler.Helpers","doc":"","ref":"Hologram.Compiler.Helpers.html"},{"type":"function","title":"Hologram.Compiler.Helpers.alias_segments/1","doc":"Returns alias segments list (without the \"Elixir\" segment at the beginning).","ref":"Hologram.Compiler.Helpers.html#alias_segments/1"},{"type":"function","title":"Examples - Hologram.Compiler.Helpers.alias_segments/1","doc":"iex> alias_segments(\"Aaa.Bbb\")\n    [:Aaa, :Bbb]\n\n    iex> alias_segments(Aaa.Bbb)\n    [:Aaa, :Bbb]","ref":"Hologram.Compiler.Helpers.html#alias_segments/1-examples"},{"type":"function","title":"Hologram.Compiler.Helpers.module/1","doc":"Builds module atom from alias segments.","ref":"Hologram.Compiler.Helpers.html#module/1"},{"type":"function","title":"Examples - Hologram.Compiler.Helpers.module/1","doc":"iex> module([:Aaa, :Bbb])\n    Aaa.Bbb","ref":"Hologram.Compiler.Helpers.html#module/1-examples"},{"type":"module","title":"Hologram.Compiler.IR","doc":"","ref":"Hologram.Compiler.IR.html"},{"type":"function","title":"Hologram.Compiler.IR.aggregate_module_funs/1","doc":"Aggregates function clauses from a module definition.","ref":"Hologram.Compiler.IR.html#aggregate_module_funs/1"},{"type":"function","title":"Returns - Hologram.Compiler.IR.aggregate_module_funs/1","doc":"A list, where each item is in the format:\n{{function_name, arity}, {visibility, [clause_1, clause_2, ...]}}","ref":"Hologram.Compiler.IR.html#aggregate_module_funs/1-returns"},{"type":"function","title":"Example - Hologram.Compiler.IR.aggregate_module_funs/1","doc":"iex> module_def = %ModuleDefinition{...}\n    iex> aggregate_module_funs(module_def)\n    [\n      {{:my_function_1, 3}, {:public, [%IR.FunctionClause{...}, %IR.FunctionClause{...}]}},\n      {{:my_function_2, 1}, {:private, [%IR.FunctionClause{...}]}}\n    ]","ref":"Hologram.Compiler.IR.html#aggregate_module_funs/1-example"},{"type":"function","title":"Hologram.Compiler.IR.for_code/2","doc":"Returns Hologram IR for the given Elixir source code.","ref":"Hologram.Compiler.IR.html#for_code/2"},{"type":"function","title":"Examples - Hologram.Compiler.IR.for_code/2","doc":"iex> for_code(\"my_fun(1, 2)\")\n    %IR.LocalFunctionCall{function: :my_fun, args: [%IR.IntegerType{value: 1}, %IR.IntegerType{value: 2}]}","ref":"Hologram.Compiler.IR.html#for_code/2-examples"},{"type":"function","title":"Hologram.Compiler.IR.for_module/2","doc":"Returns Hologram IR of the given module.\nSpecifying the module's BEAM path makes the call faster.","ref":"Hologram.Compiler.IR.html#for_module/2"},{"type":"function","title":"Examples - Hologram.Compiler.IR.for_module/2","doc":"iex> for_module(MyModule)\n    %IR.ModuleDefinition{module: MyModule, body: %IR.Block{expressions: [...]}}","ref":"Hologram.Compiler.IR.html#for_module/2-examples"},{"type":"function","title":"Hologram.Compiler.IR.for_term/1","doc":"Returns Hologram IR for the given Elixir term.\nIf the term can be represented in IR then its value is returned in the shape of {:ok, ir}.\nIf the term can't be represented in IR then an error message is returned in the shape of {:error, message}.","ref":"Hologram.Compiler.IR.html#for_term/1"},{"type":"function","title":"Examples - Hologram.Compiler.IR.for_term/1","doc":"iex> my_var = 123\n    iex> for_term(my_var)\n    {:ok, %IR.IntegerType{value: 123}}","ref":"Hologram.Compiler.IR.html#for_term/1-examples"},{"type":"function","title":"Hologram.Compiler.IR.for_term!/1","doc":"Returns Hologram IR for the given Elixir term, erroring out if the term can't be represented in IR.","ref":"Hologram.Compiler.IR.html#for_term!/1"},{"type":"function","title":"Examples - Hologram.Compiler.IR.for_term!/1","doc":"iex> my_var = 123\n    iex> for_term!(my_var)\n    %IR.IntegerType{value: 123}","ref":"Hologram.Compiler.IR.html#for_term!/1-examples"},{"type":"type","title":"Hologram.Compiler.IR.t/0","doc":"","ref":"Hologram.Compiler.IR.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.AnonymousFunctionCall","doc":"","ref":"Hologram.Compiler.IR.AnonymousFunctionCall.html"},{"type":"type","title":"Hologram.Compiler.IR.AnonymousFunctionCall.t/0","doc":"","ref":"Hologram.Compiler.IR.AnonymousFunctionCall.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.AnonymousFunctionType","doc":"","ref":"Hologram.Compiler.IR.AnonymousFunctionType.html"},{"type":"type","title":"Hologram.Compiler.IR.AnonymousFunctionType.t/0","doc":"","ref":"Hologram.Compiler.IR.AnonymousFunctionType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.AtomType","doc":"","ref":"Hologram.Compiler.IR.AtomType.html"},{"type":"type","title":"Hologram.Compiler.IR.AtomType.t/0","doc":"","ref":"Hologram.Compiler.IR.AtomType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.BitstringSegment","doc":"","ref":"Hologram.Compiler.IR.BitstringSegment.html"},{"type":"type","title":"Hologram.Compiler.IR.BitstringSegment.modifier/0","doc":"","ref":"Hologram.Compiler.IR.BitstringSegment.html#t:modifier/0"},{"type":"type","title":"Hologram.Compiler.IR.BitstringSegment.t/0","doc":"","ref":"Hologram.Compiler.IR.BitstringSegment.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.BitstringType","doc":"","ref":"Hologram.Compiler.IR.BitstringType.html"},{"type":"type","title":"Hologram.Compiler.IR.BitstringType.t/0","doc":"","ref":"Hologram.Compiler.IR.BitstringType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Block","doc":"","ref":"Hologram.Compiler.IR.Block.html"},{"type":"type","title":"Hologram.Compiler.IR.Block.t/0","doc":"","ref":"Hologram.Compiler.IR.Block.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Case","doc":"","ref":"Hologram.Compiler.IR.Case.html"},{"type":"type","title":"Hologram.Compiler.IR.Case.t/0","doc":"","ref":"Hologram.Compiler.IR.Case.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Clause","doc":"","ref":"Hologram.Compiler.IR.Clause.html"},{"type":"type","title":"Hologram.Compiler.IR.Clause.t/0","doc":"","ref":"Hologram.Compiler.IR.Clause.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Comprehension","doc":"","ref":"Hologram.Compiler.IR.Comprehension.html"},{"type":"type","title":"Hologram.Compiler.IR.Comprehension.t/0","doc":"","ref":"Hologram.Compiler.IR.Comprehension.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.ComprehensionFilter","doc":"","ref":"Hologram.Compiler.IR.ComprehensionFilter.html"},{"type":"type","title":"Hologram.Compiler.IR.ComprehensionFilter.t/0","doc":"","ref":"Hologram.Compiler.IR.ComprehensionFilter.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Cond","doc":"","ref":"Hologram.Compiler.IR.Cond.html"},{"type":"type","title":"Hologram.Compiler.IR.Cond.t/0","doc":"","ref":"Hologram.Compiler.IR.Cond.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.CondClause","doc":"","ref":"Hologram.Compiler.IR.CondClause.html"},{"type":"type","title":"Hologram.Compiler.IR.CondClause.t/0","doc":"","ref":"Hologram.Compiler.IR.CondClause.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.ConsOperator","doc":"","ref":"Hologram.Compiler.IR.ConsOperator.html"},{"type":"type","title":"Hologram.Compiler.IR.ConsOperator.t/0","doc":"","ref":"Hologram.Compiler.IR.ConsOperator.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.DotOperator","doc":"","ref":"Hologram.Compiler.IR.DotOperator.html"},{"type":"type","title":"Hologram.Compiler.IR.DotOperator.t/0","doc":"","ref":"Hologram.Compiler.IR.DotOperator.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.FloatType","doc":"","ref":"Hologram.Compiler.IR.FloatType.html"},{"type":"type","title":"Hologram.Compiler.IR.FloatType.t/0","doc":"","ref":"Hologram.Compiler.IR.FloatType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.FunctionClause","doc":"","ref":"Hologram.Compiler.IR.FunctionClause.html"},{"type":"type","title":"Hologram.Compiler.IR.FunctionClause.t/0","doc":"","ref":"Hologram.Compiler.IR.FunctionClause.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.FunctionDefinition","doc":"","ref":"Hologram.Compiler.IR.FunctionDefinition.html"},{"type":"type","title":"Hologram.Compiler.IR.FunctionDefinition.t/0","doc":"","ref":"Hologram.Compiler.IR.FunctionDefinition.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.IgnoredExpression","doc":"","ref":"Hologram.Compiler.IR.IgnoredExpression.html"},{"type":"type","title":"Hologram.Compiler.IR.IgnoredExpression.t/0","doc":"","ref":"Hologram.Compiler.IR.IgnoredExpression.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.IntegerType","doc":"","ref":"Hologram.Compiler.IR.IntegerType.html"},{"type":"type","title":"Hologram.Compiler.IR.IntegerType.t/0","doc":"","ref":"Hologram.Compiler.IR.IntegerType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.ListType","doc":"","ref":"Hologram.Compiler.IR.ListType.html"},{"type":"type","title":"Hologram.Compiler.IR.ListType.t/0","doc":"","ref":"Hologram.Compiler.IR.ListType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.LocalFunctionCall","doc":"","ref":"Hologram.Compiler.IR.LocalFunctionCall.html"},{"type":"type","title":"Hologram.Compiler.IR.LocalFunctionCall.t/0","doc":"","ref":"Hologram.Compiler.IR.LocalFunctionCall.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.MapType","doc":"","ref":"Hologram.Compiler.IR.MapType.html"},{"type":"type","title":"Hologram.Compiler.IR.MapType.t/0","doc":"","ref":"Hologram.Compiler.IR.MapType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.MatchOperator","doc":"","ref":"Hologram.Compiler.IR.MatchOperator.html"},{"type":"type","title":"Hologram.Compiler.IR.MatchOperator.t/0","doc":"","ref":"Hologram.Compiler.IR.MatchOperator.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.MatchPlaceholder","doc":"","ref":"Hologram.Compiler.IR.MatchPlaceholder.html"},{"type":"type","title":"Hologram.Compiler.IR.MatchPlaceholder.t/0","doc":"","ref":"Hologram.Compiler.IR.MatchPlaceholder.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.ModuleAttributeOperator","doc":"","ref":"Hologram.Compiler.IR.ModuleAttributeOperator.html"},{"type":"type","title":"Hologram.Compiler.IR.ModuleAttributeOperator.t/0","doc":"","ref":"Hologram.Compiler.IR.ModuleAttributeOperator.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.ModuleDefinition","doc":"","ref":"Hologram.Compiler.IR.ModuleDefinition.html"},{"type":"type","title":"Hologram.Compiler.IR.ModuleDefinition.t/0","doc":"","ref":"Hologram.Compiler.IR.ModuleDefinition.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.PIDType","doc":"","ref":"Hologram.Compiler.IR.PIDType.html"},{"type":"type","title":"Hologram.Compiler.IR.PIDType.t/0","doc":"","ref":"Hologram.Compiler.IR.PIDType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.PinOperator","doc":"","ref":"Hologram.Compiler.IR.PinOperator.html"},{"type":"type","title":"Hologram.Compiler.IR.PinOperator.t/0","doc":"","ref":"Hologram.Compiler.IR.PinOperator.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.PortType","doc":"","ref":"Hologram.Compiler.IR.PortType.html"},{"type":"type","title":"Hologram.Compiler.IR.PortType.t/0","doc":"","ref":"Hologram.Compiler.IR.PortType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.ReferenceType","doc":"","ref":"Hologram.Compiler.IR.ReferenceType.html"},{"type":"type","title":"Hologram.Compiler.IR.ReferenceType.t/0","doc":"","ref":"Hologram.Compiler.IR.ReferenceType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.RemoteFunctionCall","doc":"","ref":"Hologram.Compiler.IR.RemoteFunctionCall.html"},{"type":"type","title":"Hologram.Compiler.IR.RemoteFunctionCall.t/0","doc":"","ref":"Hologram.Compiler.IR.RemoteFunctionCall.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.StringType","doc":"","ref":"Hologram.Compiler.IR.StringType.html"},{"type":"type","title":"Hologram.Compiler.IR.StringType.t/0","doc":"","ref":"Hologram.Compiler.IR.StringType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Try","doc":"","ref":"Hologram.Compiler.IR.Try.html"},{"type":"type","title":"Hologram.Compiler.IR.Try.t/0","doc":"","ref":"Hologram.Compiler.IR.Try.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.TryCatchClause","doc":"","ref":"Hologram.Compiler.IR.TryCatchClause.html"},{"type":"type","title":"Hologram.Compiler.IR.TryCatchClause.t/0","doc":"","ref":"Hologram.Compiler.IR.TryCatchClause.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.TryRescueClause","doc":"","ref":"Hologram.Compiler.IR.TryRescueClause.html"},{"type":"type","title":"Hologram.Compiler.IR.TryRescueClause.t/0","doc":"","ref":"Hologram.Compiler.IR.TryRescueClause.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.TupleType","doc":"","ref":"Hologram.Compiler.IR.TupleType.html"},{"type":"type","title":"Hologram.Compiler.IR.TupleType.t/0","doc":"","ref":"Hologram.Compiler.IR.TupleType.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.Variable","doc":"","ref":"Hologram.Compiler.IR.Variable.html"},{"type":"type","title":"Hologram.Compiler.IR.Variable.t/0","doc":"","ref":"Hologram.Compiler.IR.Variable.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.IR.With","doc":"","ref":"Hologram.Compiler.IR.With.html"},{"type":"type","title":"Hologram.Compiler.IR.With.t/0","doc":"","ref":"Hologram.Compiler.IR.With.html#t:t/0"},{"type":"module","title":"Hologram.Compiler.Normalizer","doc":"","ref":"Hologram.Compiler.Normalizer.html"},{"type":"function","title":"Hologram.Compiler.Normalizer.normalize/1","doc":"Normalizes Elixir AST by ensuring that:\n* single expression blocks are wrapped in __block__ tuple\n* alias atoms are wrapped in __aliases__ tuple\n* unquote fragments are expanded","ref":"Hologram.Compiler.Normalizer.html#normalize/1"},{"type":"function","title":"Examples - Hologram.Compiler.Normalizer.normalize/1","doc":"iex> ast = Code.string_to_quoted!(\"cond do true -> 123 end\")\n    {:cond, [line: 1], [[do: [{:->, [line: 1], [[true], 987]}]]]}\n    iex> normalize(ast)\n    {:cond, [line: 1], [[do: [{:->, [line: 1], [[true], {:__block__, [], [987]}]}]]]}","ref":"Hologram.Compiler.Normalizer.html#normalize/1-examples"},{"type":"module","title":"Hologram.Compiler.Transformer","doc":"","ref":"Hologram.Compiler.Transformer.html"},{"type":"function","title":"Hologram.Compiler.Transformer.debug/3","doc":"Prints debug info for intercepted transform/2 calls.","ref":"Hologram.Compiler.Transformer.html#debug/3"},{"type":"function","title":"Hologram.Compiler.Transformer.transform/2","doc":"Transforms Elixir AST to Hologram IR.","ref":"Hologram.Compiler.Transformer.html#transform/2"},{"type":"function","title":"Examples - Hologram.Compiler.Transformer.transform/2","doc":"iex> ast = quote do {1, 2, 3} end\n    {:{}, [], [1, 2, 3]}\n    iex> transform(ast)\n    %IR.TupleType{data: [%IR.IntegerType{value: 1}, %IR.IntegerType{value: 2}, %IR.IntegerType{value: 3}]}","ref":"Hologram.Compiler.Transformer.html#transform/2-examples"},{"type":"behaviour","title":"Hologram.Component","doc":"","ref":"Hologram.Component.html"},{"type":"function","title":"Hologram.Component.colocated_template_path/1","doc":"Resolves the colocated template path for the given component module given its file path.","ref":"Hologram.Component.html#colocated_template_path/1"},{"type":"callback","title":"Hologram.Component.init/3","doc":"Initializes component and server structs (when run on the server).","ref":"Hologram.Component.html#c:init/3"},{"type":"function","title":"Hologram.Component.maybe_define_template_fun/2","doc":"Returns the AST of template/0 function definition that uses markup fetched from the give template file.\nIf the given template file doesn't exist nil is returned.","ref":"Hologram.Component.html#maybe_define_template_fun/2"},{"type":"macro","title":"Hologram.Component.prop/3","doc":"Accumulates the given property definition in __props__ module attribute.","ref":"Hologram.Component.html#prop/3"},{"type":"function","title":"Hologram.Component.put_action/2","doc":"Puts the given action spec to the component or server struct's next_action field.\nNext action will be executed by the runtime synchronously.","ref":"Hologram.Component.html#put_action/2"},{"type":"function","title":"Hologram.Component.put_action/3","doc":"Puts the given action spec to the component or server struct's next_action field.\nNext action will be executed by the runtime synchronously.","ref":"Hologram.Component.html#put_action/3"},{"type":"function","title":"Hologram.Component.put_command/2","doc":"Puts the given command spec to the component's next_command field.\nNext command will be sent asynchronously to the server.","ref":"Hologram.Component.html#put_command/2"},{"type":"function","title":"Hologram.Component.put_command/3","doc":"Puts the given command spec to the component's next_command field.\nNext command will be sent asynchronously to the server.","ref":"Hologram.Component.html#put_command/3"},{"type":"function","title":"Hologram.Component.put_context/3","doc":"Puts the given key-value pair to the component's emitted_context field.\nContext emitted by a component is available to all of its child nodes.","ref":"Hologram.Component.html#put_context/3"},{"type":"function","title":"Hologram.Component.put_page/2","doc":"Puts the given page module to the component's next_page field.\nThe client will navigate to this page asynchronously after the current action finished executing.","ref":"Hologram.Component.html#put_page/2"},{"type":"function","title":"Hologram.Component.put_page/3","doc":"Puts the given page module and params to the component's next_page field (as a tuple).\nThe client will navigate to this page asynchronously after the current action finished executing.","ref":"Hologram.Component.html#put_page/3"},{"type":"function","title":"Hologram.Component.put_state/2","doc":"Puts the given key-value entries to the component state.","ref":"Hologram.Component.html#put_state/2"},{"type":"function","title":"Hologram.Component.put_state/3","doc":"If the second arg is a list of keys representing a component state path\nit puts the value in the nested component state path,\notherwise it puts the given key-value pair to the component state.","ref":"Hologram.Component.html#put_state/3"},{"type":"function","title":"Hologram.Component.register_props_accumulator/0","doc":"Returns the AST of code that registers __props__ module attribute.","ref":"Hologram.Component.html#register_props_accumulator/0"},{"type":"type","title":"Hologram.Component.t/0","doc":"","ref":"Hologram.Component.html#t:t/0"},{"type":"callback","title":"Hologram.Component.template/0","doc":"Returns a template in the form of an anonymous function that given variable bindings returns a DOM.","ref":"Hologram.Component.html#c:template/0"},{"type":"module","title":"Hologram.Component.Action","doc":"","ref":"Hologram.Component.Action.html"},{"type":"type","title":"Hologram.Component.Action.t/0","doc":"","ref":"Hologram.Component.Action.html#t:t/0"},{"type":"module","title":"Hologram.Component.Command","doc":"","ref":"Hologram.Component.Command.html"},{"type":"type","title":"Hologram.Component.Command.t/0","doc":"","ref":"Hologram.Component.Command.html#t:t/0"},{"type":"module","title":"Hologram.Controller","doc":"","ref":"Hologram.Controller.html"},{"type":"function","title":"Hologram.Controller.extract_params/2","doc":"Extracts param values from the given URL path corresponding to the route of the given page module.","ref":"Hologram.Controller.html#extract_params/2"},{"type":"function","title":"Hologram.Controller.handle_request/2","doc":"Handles the page request by building HTML response body and halting the Plug pipeline.","ref":"Hologram.Controller.html#handle_request/2"},{"type":"module","title":"Hologram.Endpoint","doc":"","ref":"Hologram.Endpoint.html"},{"type":"macro","title":"Hologram.Endpoint.hologram_socket/0","doc":"","ref":"Hologram.Endpoint.html#hologram_socket/0"},{"type":"module","title":"Hologram.LiveReload","doc":"","ref":"Hologram.LiveReload.html"},{"type":"function","title":"Hologram.LiveReload.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hologram.LiveReload.html#child_spec/1"},{"type":"function","title":"Hologram.LiveReload.start_link/1","doc":"Starts live reload process.","ref":"Hologram.LiveReload.html#start_link/1"},{"type":"behaviour","title":"Hologram.Page","doc":"","ref":"Hologram.Page.html"},{"type":"function","title":"Hologram.Page.cast_params/2","doc":"Casts page params string values to types specified with param/2 macro.","ref":"Hologram.Page.html#cast_params/2"},{"type":"callback","title":"Hologram.Page.init/3","doc":"Initializes component and server structs (when run on the server).","ref":"Hologram.Page.html#c:init/3"},{"type":"macro","title":"Hologram.Page.layout/2","doc":"Defines page's layout metadata functions.","ref":"Hologram.Page.html#layout/2"},{"type":"macro","title":"Hologram.Page.param/3","doc":"Accumulates the given param definition in __params__ module attribute.","ref":"Hologram.Page.html#param/3"},{"type":"function","title":"Hologram.Page.register_params_accumulator/0","doc":"Returns the AST of code that registers __params__ module attribute.","ref":"Hologram.Page.html#register_params_accumulator/0"},{"type":"macro","title":"Hologram.Page.route/1","doc":"Defines page's route metadata functions.","ref":"Hologram.Page.html#route/1"},{"type":"callback","title":"Hologram.Page.template/0","doc":"Returns a template in the form of an anonymous function that given variable bindings returns a DOM.","ref":"Hologram.Page.html#c:template/0"},{"type":"module","title":"Hologram.Reflection","doc":"","ref":"Hologram.Reflection.html"},{"type":"function","title":"Hologram.Reflection.alias?/1","doc":"Determines whether the given term is an alias.","ref":"Hologram.Reflection.html#alias?/1"},{"type":"function","title":"Examples - Hologram.Reflection.alias?/1","doc":"iex> alias?(Calendar.ISO)\n    true\n\n    iex> alias?(:abc)\n    false","ref":"Hologram.Reflection.html#alias?/1-examples"},{"type":"function","title":"Hologram.Reflection.beam_defs/1","doc":"Returns BEAM definitions for the given BEAM file path.","ref":"Hologram.Reflection.html#beam_defs/1"},{"type":"function","title":"Examples - Hologram.Reflection.beam_defs/1","doc":"iex> beam_path = ~c\"/Users/bartblast/Projects/hologram/_build/dev/lib/hologram/ebin/Elixir.Hologram.Reflection.beam\"  \n    iex> beam_defs()\n    [\n      ...,\n      {{:alias?, 1}, :def, [line: 14],\n      [\n        {[line: 16], [{:term, [version: 0, line: 16], nil}],\n          [\n            {{:., [line: 16], [:erlang, :is_atom]}, [line: 16],\n            [{:term, [version: 0, line: 16], nil}]}\n          ],\n          {{:., [line: 19], [String, :starts_with?]}, [line: 19],\n          [\n            {{:., [line: 18], [String.Chars, :to_string]}, [line: 18],\n              [{:term, [version: 0, line: 17], nil}]},\n            \"Elixir.\"\n          ]}},\n        {[line: 22], [{:_, [line: 22], nil}], [], false}\n      ]}\n    ]","ref":"Hologram.Reflection.html#beam_defs/1-examples"},{"type":"function","title":"Hologram.Reflection.build_dir/0","doc":"Returns the build directory path.","ref":"Hologram.Reflection.html#build_dir/0"},{"type":"function","title":"Hologram.Reflection.call_graph_dump_file_name/0","doc":"Returns the call graph dump file name.","ref":"Hologram.Reflection.html#call_graph_dump_file_name/0"},{"type":"function","title":"Hologram.Reflection.component?/1","doc":"Returns true if the given term is a component module (a module that has a \"use Hologram.Component\" directive)\nOtherwise false is returned.","ref":"Hologram.Reflection.html#component?/1"},{"type":"function","title":"Examples - Hologram.Reflection.component?/1","doc":"iex> component?(MyComponent)\n    true\n\n    iex> component?(Hologram.Reflection)\n    false","ref":"Hologram.Reflection.html#component?/1-examples"},{"type":"function","title":"Hologram.Reflection.ecto_schema?/1","doc":"Returns true if the given term is an Ecto schema module, or false otherwise.","ref":"Hologram.Reflection.html#ecto_schema?/1"},{"type":"function","title":"Hologram.Reflection.elixir_module?/1","doc":"Returns true if the given term is an existing Elixir module, or false otherwise.","ref":"Hologram.Reflection.html#elixir_module?/1"},{"type":"function","title":"Examples - Hologram.Reflection.elixir_module?/1","doc":"iex> elixir_module?(Calendar.ISO)\n    true\n\n    iex> elixir_module?(MyModule)\n    false\n\n    iex> elixir_module?(:my_module)\n    false\n    \n    iex> elixir_module?(123)\n    false","ref":"Hologram.Reflection.html#elixir_module?/1-examples"},{"type":"function","title":"Hologram.Reflection.erlang_module?/1","doc":"Returns true if the given term is an existing Erlang module, or false otherwise.","ref":"Hologram.Reflection.html#erlang_module?/1"},{"type":"function","title":"Examples - Hologram.Reflection.erlang_module?/1","doc":"iex> erlang_module?(:maps)\n    true\n\n    iex> erlang_module?(:my_module)\n    false\n    \n    iex> erlang_module?(Calendar.ISO)\n    false \n\n    iex> erlang_module?(123)\n    false","ref":"Hologram.Reflection.html#erlang_module?/1-examples"},{"type":"function","title":"Hologram.Reflection.has_function?/3","doc":"Returns true if module contains a public function with the given arity, otherwise false.\n\nKernel.function_exported?/3 does not load the module in case it is not loaded\n(in such cases it would return false even when the module has the given function).","ref":"Hologram.Reflection.html#has_function?/3"},{"type":"function","title":"Hologram.Reflection.has_struct?/1","doc":"Determines whether the given module defines its struct.","ref":"Hologram.Reflection.html#has_struct?/1"},{"type":"function","title":"Hologram.Reflection.ir_plt_dump_file_name/0","doc":"Returns the IR PLT dump file name.","ref":"Hologram.Reflection.html#ir_plt_dump_file_name/0"},{"type":"function","title":"Hologram.Reflection.list_all_otp_apps/0","doc":"Lists all OTP applications, both loaded and not loaded.","ref":"Hologram.Reflection.html#list_all_otp_apps/0"},{"type":"function","title":"Hologram.Reflection.list_elixir_modules/0","doc":"Lists Elixir modules belonging to any of the loaded OTP applications used by the project (except :hex).\nElixir modules listed in @ignored_modules module attribute, Elixir modules without a BEAM file, and Erlang modules are filtered out.\nThe project OTP application is included.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/reflection/list_elixir_modules_0/README.md","ref":"Hologram.Reflection.html#list_elixir_modules/0"},{"type":"function","title":"Hologram.Reflection.list_elixir_modules/1","doc":"Lists Elixir modules belonging to the given OTP apps.\nElixir modules listed in @ignored_modules module attribute and Erlang modules are filtered out.","ref":"Hologram.Reflection.html#list_elixir_modules/1"},{"type":"function","title":"Hologram.Reflection.list_loaded_otp_apps/0","doc":"Lists loaded OTP applications.","ref":"Hologram.Reflection.html#list_loaded_otp_apps/0"},{"type":"function","title":"Examples - Hologram.Reflection.list_loaded_otp_apps/0","doc":"iex> list_loaded_otp_apps()\n  [\n    :inets,\n    :logger,\n    :stdlib,\n    :file_system,\n    ...\n  ]","ref":"Hologram.Reflection.html#list_loaded_otp_apps/0-examples"},{"type":"function","title":"Hologram.Reflection.list_pages/0","doc":"Lists Elixir modules which are Hologram pages and that belong to any of the OTP apps in the project.\n\nBenchmark: https://github.com/bartblast/hologram/blob/master/benchmarks/reflection/list_pages_0/README.md","ref":"Hologram.Reflection.html#list_pages/0"},{"type":"function","title":"Hologram.Reflection.list_protocol_implementations/1","doc":"Returns the list of modules that are implementations of the given protocol.","ref":"Hologram.Reflection.html#list_protocol_implementations/1"},{"type":"function","title":"Hologram.Reflection.list_std_lib_elixir_modules/0","doc":"Lists standard library Elixir modules, e.g. DateTime, Kernel, Calendar.ISO, etc.\nElixir modules listed in @ignored_modules module attribute, Elixir modules without a BEAM file, and Erlang modules are filtered out.","ref":"Hologram.Reflection.html#list_std_lib_elixir_modules/0"},{"type":"function","title":"Hologram.Reflection.module?/1","doc":"Returns true if the given term is an existing (Elixir or Erlang) module, or false otherwise.","ref":"Hologram.Reflection.html#module?/1"},{"type":"function","title":"Examples - Hologram.Reflection.module?/1","doc":"iex> module?(Calendar.ISO)\n    true\n\n    iex> module?(MyModule)\n    false\n    \n    iex> module?(:maps)\n    true\n\n    iex> module?(:my_module)\n    false\n    \n    iex> module?(123)\n    false","ref":"Hologram.Reflection.html#module?/1-examples"},{"type":"function","title":"Hologram.Reflection.module_beam_path_plt_dump_file_name/0","doc":"Returns the module BEAM path PLT dump file name.","ref":"Hologram.Reflection.html#module_beam_path_plt_dump_file_name/0"},{"type":"function","title":"Hologram.Reflection.module_digest_plt_dump_file_name/0","doc":"Returns the module digest PLT dump file name.","ref":"Hologram.Reflection.html#module_digest_plt_dump_file_name/0"},{"type":"function","title":"Hologram.Reflection.module_name/1","doc":"Returns the module name without \"Elixir\" prefix at the beginning.","ref":"Hologram.Reflection.html#module_name/1"},{"type":"function","title":"Examples - Hologram.Reflection.module_name/1","doc":"iex> module_name(Aaa.Bbb)\n    \"Aaa.Bbb\"","ref":"Hologram.Reflection.html#module_name/1-examples"},{"type":"function","title":"Hologram.Reflection.otp_app/0","doc":"Returns the project OTP application name.","ref":"Hologram.Reflection.html#otp_app/0"},{"type":"function","title":"Hologram.Reflection.page?/1","doc":"Returns true if the given term is a page module (a module that has a \"use Hologram.Page\" directive)\nOtherwise false is returned.","ref":"Hologram.Reflection.html#page?/1"},{"type":"function","title":"Examples - Hologram.Reflection.page?/1","doc":"iex> page?(MyPage)\n    true\n\n    iex> page?(Hologram.Reflection)\n    false","ref":"Hologram.Reflection.html#page?/1-examples"},{"type":"function","title":"Hologram.Reflection.page_digest_plt_dump_file_name/0","doc":"Returns the page digest PLT dump file name.","ref":"Hologram.Reflection.html#page_digest_plt_dump_file_name/0"},{"type":"function","title":"Hologram.Reflection.phoenix_endpoint/0","doc":"Determines the app's Phoenix endpoint module.","ref":"Hologram.Reflection.html#phoenix_endpoint/0"},{"type":"function","title":"Hologram.Reflection.protocol?/1","doc":"Returns true if the given term is a protocol module, or false otherwise.","ref":"Hologram.Reflection.html#protocol?/1"},{"type":"function","title":"Hologram.Reflection.release_priv_dir/0","doc":"Returns the release priv dir path.","ref":"Hologram.Reflection.html#release_priv_dir/0"},{"type":"function","title":"Hologram.Reflection.release_static_dir/0","doc":"Returns the release static dir path.","ref":"Hologram.Reflection.html#release_static_dir/0"},{"type":"function","title":"Hologram.Reflection.root_dir/0","doc":"Returns the absolute dir path of the project.","ref":"Hologram.Reflection.html#root_dir/0"},{"type":"function","title":"Examples - Hologram.Reflection.root_dir/0","doc":"iex> root_dir()\n    \"/Users/bartblast/Projects/my_project\"","ref":"Hologram.Reflection.html#root_dir/0-examples"},{"type":"function","title":"Hologram.Reflection.root_priv_dir/0","doc":"Returns the absolute path of the project priv dir for Hologram.","ref":"Hologram.Reflection.html#root_priv_dir/0"},{"type":"function","title":"Examples - Hologram.Reflection.root_priv_dir/0","doc":"iex> root_priv_dir()\n    \"/Users/bartblast/Projects/my_project/priv/hologram\"","ref":"Hologram.Reflection.html#root_priv_dir/0-examples"},{"type":"function","title":"Hologram.Reflection.source_path/1","doc":"Returns the file path of the given module's source code.","ref":"Hologram.Reflection.html#source_path/1"},{"type":"function","title":"Hologram.Reflection.templatable?/1","doc":"Returns true if the given term is a component (a module that has a \"use Hologram.Component\" directive)\nor a page (a module that has a \"use Hologram.Page\" directive).\nOtherwise false is returned.","ref":"Hologram.Reflection.html#templatable?/1"},{"type":"function","title":"Examples - Hologram.Reflection.templatable?/1","doc":"iex> component?(MyComponent)\n    true\n    \n    iex> component?(MyPage)\n    true\n\n    iex> component?(Hologram.Reflection)\n    false","ref":"Hologram.Reflection.html#templatable?/1-examples"},{"type":"function","title":"Hologram.Reflection.tmp_dir/0","doc":"Returns the absolute path of the tmp directory.","ref":"Hologram.Reflection.html#tmp_dir/0"},{"type":"function","title":"Examples - Hologram.Reflection.tmp_dir/0","doc":"iex> tmp_dir()\n    \"/Users/bartblast/Projects/my_project/tmp\"","ref":"Hologram.Reflection.html#tmp_dir/0-examples"},{"type":"module","title":"Hologram.Router","doc":"","ref":"Hologram.Router.html"},{"type":"module","title":"Hologram.Router.Helpers","doc":"","ref":"Hologram.Router.Helpers.html"},{"type":"function","title":"Hologram.Router.Helpers.asset_path/1","doc":"Retrieves the asset path, including the digest, for the specified static file within the static directory.\nIf there's no corresponding entry for the provided static file, the static file path itself will be returned.","ref":"Hologram.Router.Helpers.html#asset_path/1"},{"type":"function","title":"Hologram.Router.Helpers.page_bundle_path/1","doc":"Returns the relative URL of a page's JavaScript bundle using the page's digest.","ref":"Hologram.Router.Helpers.html#page_bundle_path/1"},{"type":"function","title":"Hologram.Router.Helpers.page_path/1","doc":"Builds relative URL for the given page module or a tuple of a page module and params.","ref":"Hologram.Router.Helpers.html#page_path/1"},{"type":"function","title":"Hologram.Router.Helpers.page_path/2","doc":"Builds relative URL for the given page module and params.","ref":"Hologram.Router.Helpers.html#page_path/2"},{"type":"behaviour","title":"Hologram.Router.PageModuleResolver","doc":"","ref":"Hologram.Router.PageModuleResolver.html"},{"type":"function","title":"Hologram.Router.PageModuleResolver.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hologram.Router.PageModuleResolver.html#child_spec/1"},{"type":"function","title":"Hologram.Router.PageModuleResolver.persistent_term_key/0","doc":"Returns the implementation of the page module resolver's persistent term key.","ref":"Hologram.Router.PageModuleResolver.html#persistent_term_key/0"},{"type":"callback","title":"Hologram.Router.PageModuleResolver.persistent_term_key/0","doc":"Returns the key of the persistent term used by the page module resolver registered process.","ref":"Hologram.Router.PageModuleResolver.html#c:persistent_term_key/0"},{"type":"function","title":"Hologram.Router.PageModuleResolver.reload/0","doc":"Reloads the persistent term that stores the search tree used for page module resolving.","ref":"Hologram.Router.PageModuleResolver.html#reload/0"},{"type":"function","title":"Hologram.Router.PageModuleResolver.resolve/1","doc":"Given a request path it returns the page module that handles it.","ref":"Hologram.Router.PageModuleResolver.html#resolve/1"},{"type":"function","title":"Hologram.Router.PageModuleResolver.start_link/1","doc":"Starts page module resolver process.","ref":"Hologram.Router.PageModuleResolver.html#start_link/1"},{"type":"module","title":"Hologram.Router.SearchTree","doc":"","ref":"Hologram.Router.SearchTree.html"},{"type":"function","title":"Hologram.Router.SearchTree.add_route/3","doc":"Adds route info for the given URL path to the search tree by creating all nodes related to that URL path.","ref":"Hologram.Router.SearchTree.html#add_route/3"},{"type":"function","title":"Hologram.Router.SearchTree.match_route/2","doc":"Matches the given URL path against the search tree.","ref":"Hologram.Router.SearchTree.html#match_route/2"},{"type":"module","title":"Hologram.Router.SearchTree.Node","doc":"","ref":"Hologram.Router.SearchTree.Node.html"},{"type":"type","title":"Hologram.Router.SearchTree.Node.t/0","doc":"","ref":"Hologram.Router.SearchTree.Node.html#t:t/0"},{"type":"module","title":"Hologram.Server","doc":"","ref":"Hologram.Server.html"},{"type":"type","title":"Hologram.Server.t/0","doc":"","ref":"Hologram.Server.html#t:t/0"},{"type":"module","title":"Hologram.Socket","doc":"","ref":"Hologram.Socket.html"},{"type":"module","title":"Hologram.Socket.Channel","doc":"","ref":"Hologram.Socket.Channel.html"},{"type":"function","title":"Hologram.Socket.Channel.child_spec/1","doc":"","ref":"Hologram.Socket.Channel.html#child_spec/1"},{"type":"function","title":"Hologram.Socket.Channel.start_link/1","doc":"","ref":"Hologram.Socket.Channel.html#start_link/1"},{"type":"module","title":"Hologram.Socket.Decoder","doc":"","ref":"Hologram.Socket.Decoder.html"},{"type":"function","title":"Hologram.Socket.Decoder.atoms_whitelist/0","doc":"Returns the atoms whitelist related to client DOM events.","ref":"Hologram.Socket.Decoder.html#atoms_whitelist/0"},{"type":"function","title":"Hologram.Socket.Decoder.decode/1","doc":"Decodes a term serialized by the client and pre-decoded from JSON.","ref":"Hologram.Socket.Decoder.html#decode/1"},{"type":"module","title":"Hologram.Template","doc":"","ref":"Hologram.Template.html"},{"type":"function","title":"Hologram.Template.dom_ast/1","doc":"Builds DOM AST from the given template markup.","ref":"Hologram.Template.html#dom_ast/1"},{"type":"function","title":"Examples - Hologram.Template.dom_ast/1","doc":"iex> dom_ast(\" content \")\n    [{:{}, [line: 1], [:element, \"div\", [], [{:text, \"content\"}]]}]","ref":"Hologram.Template.html#dom_ast/1-examples"},{"type":"macro","title":"Hologram.Template.sigil_H/2","doc":"","ref":"Hologram.Template.html#sigil_H/2"},{"type":"module","title":"Hologram.Template.DOM","doc":"","ref":"Hologram.Template.DOM.html"},{"type":"function","title":"Hologram.Template.DOM.build_ast/1","doc":"Builds DOM AST from the given parsed tags.","ref":"Hologram.Template.DOM.html#build_ast/1"},{"type":"function","title":"Examples - Hologram.Template.DOM.build_ast/1","doc":"iex> tags = [{:start_tag, {\"div, []}}, {:text, \"abc\"}, {:end_tag, \"div\"}]\n    iex> build_ast(tags)\n    [{:{}, [line: 1], [:element, \"div\", [], [{:text, \"abc\"}]]}]","ref":"Hologram.Template.DOM.html#build_ast/1-examples"},{"type":"type","title":"Hologram.Template.DOM.dom_node/0","doc":"","ref":"Hologram.Template.DOM.html#t:dom_node/0"},{"type":"type","title":"Hologram.Template.DOM.t/0","doc":"","ref":"Hologram.Template.DOM.html#t:t/0"},{"type":"module","title":"Hologram.Template.Helpers","doc":"","ref":"Hologram.Template.Helpers.html"},{"type":"function","title":"Hologram.Template.Helpers.tag_type/1","doc":"Determines whether the given tag is an element or a component.","ref":"Hologram.Template.Helpers.html#tag_type/1"},{"type":"function","title":"Examples - Hologram.Template.Helpers.tag_type/1","doc":"iex> tag_type(\"div\")\n    :element\n\n    iex> tag_type(\"MyComponent\")\n    :component","ref":"Hologram.Template.Helpers.html#tag_type/1-examples"},{"type":"function","title":"Hologram.Template.Helpers.void_element?/1","doc":"Determines whether the given tag name belongs to a void element.","ref":"Hologram.Template.Helpers.html#void_element?/1"},{"type":"function","title":"Examples - Hologram.Template.Helpers.void_element?/1","doc":"iex> void_element?(\"br\")\n    true\n\n    iex> void_element?(\"div\")\n    false","ref":"Hologram.Template.Helpers.html#void_element?/1-examples"},{"type":"module","title":"Hologram.Template.Parser","doc":"","ref":"Hologram.Template.Parser.html"},{"type":"function","title":"Hologram.Template.Parser.debug/3","doc":"Prints debug info for intercepted parse/3 calls.","ref":"Hologram.Template.Parser.html#debug/3"},{"type":"function","title":"Hologram.Template.Parser.parse_markup/1","doc":"Parses markup into tags.","ref":"Hologram.Template.Parser.html#parse_markup/1"},{"type":"function","title":"Examples - Hologram.Template.Parser.parse_markup/1","doc":"iex> markup = \"  \"\n    iex> parse_markup(markup)\n    [start_tag: {\"div\", [{\"id\", [text: \"test\"]}]}, end_tag: \"div\"]","ref":"Hologram.Template.Parser.html#parse_markup/1-examples"},{"type":"function","title":"Hologram.Template.Parser.parse_tokens/3","doc":"Parses tokens into tags.","ref":"Hologram.Template.Parser.html#parse_tokens/3"},{"type":"function","title":"Examples - Hologram.Template.Parser.parse_tokens/3","doc":"iex> tokens = [\n    ...>   symbol: \"<\",\n    ...>   string: \"div\",\n    ...>   whitespace: \" \",\n    ...>   string: \"id\",\n    ...>   symbol: \"=\",\n    ...>   symbol: \"\"\",\n    ...>   string: \"test\",\n    ...>   symbol: \"\"\",\n    ...>   symbol: \">\",\n    ...>   symbol: \"</\",\n    ...>   string: \"div\",\n    ...>   symbol: \">\"\n    ...> ]\n    iex> parse_tokens(tokens)\n    [start_tag: {\"div\", [{\"id\", [text: \"test\"]}]}, end_tag: \"div\"]","ref":"Hologram.Template.Parser.html#parse_tokens/3-examples"},{"type":"type","title":"Hologram.Template.Parser.parsed_tag/0","doc":"","ref":"Hologram.Template.Parser.html#t:parsed_tag/0"},{"type":"type","title":"Hologram.Template.Parser.status/0","doc":"","ref":"Hologram.Template.Parser.html#t:status/0"},{"type":"module","title":"Hologram.Template.Parser.Context","doc":"","ref":"Hologram.Template.Parser.Context.html"},{"type":"type","title":"Hologram.Template.Parser.Context.attribute_value_part/0","doc":"","ref":"Hologram.Template.Parser.Context.html#t:attribute_value_part/0"},{"type":"type","title":"Hologram.Template.Parser.Context.delimiter/0","doc":"","ref":"Hologram.Template.Parser.Context.html#t:delimiter/0"},{"type":"type","title":"Hologram.Template.Parser.Context.t/0","doc":"","ref":"Hologram.Template.Parser.Context.html#t:t/0"},{"type":"module","title":"Hologram.Template.Renderer","doc":"","ref":"Hologram.Template.Renderer.html"},{"type":"function","title":"Hologram.Template.Renderer.render_dom/2","doc":"Renders the given DOM.","ref":"Hologram.Template.Renderer.html#render_dom/2"},{"type":"function","title":"Examples - Hologram.Template.Renderer.render_dom/2","doc":"iex> dom = {:component, MyModule, [{\"cid\", [text: \"my_component\"]}], []}\n    iex> render_dom(dom, %Env{})\n    {\n      \" state_a = 1, state_b = 2 \",\n      %{\"my_component\" => %{module: MyModule, struct: %Component{state: %{a: 1, b: 2}}}}\n    }","ref":"Hologram.Template.Renderer.html#render_dom/2-examples"},{"type":"function","title":"Hologram.Template.Renderer.render_page/3","doc":"Renders the given page.","ref":"Hologram.Template.Renderer.html#render_page/3"},{"type":"function","title":"Examples - Hologram.Template.Renderer.render_page/3","doc":"iex> render_page(MyPage, %{param: \"value\"}, initial_page?: true)\n    {\n      \" full page content including layout \",\n      %{\"page\" => %{module: MyPage, struct: %Component{state: %{a: 1, b: 2}}}}\n    }","ref":"Hologram.Template.Renderer.html#render_page/3-examples"},{"type":"module","title":"Hologram.Template.Renderer.Env","doc":"","ref":"Hologram.Template.Renderer.Env.html"},{"type":"type","title":"Hologram.Template.Renderer.Env.t/0","doc":"","ref":"Hologram.Template.Renderer.Env.html#t:t/0"},{"type":"module","title":"Hologram.Template.Tokenizer","doc":"","ref":"Hologram.Template.Tokenizer.html"},{"type":"type","title":"Hologram.Template.Tokenizer.token/0","doc":"","ref":"Hologram.Template.Tokenizer.html#t:token/0"},{"type":"function","title":"Hologram.Template.Tokenizer.tokenize/1","doc":"Splits template markup into a list of tokens.","ref":"Hologram.Template.Tokenizer.html#tokenize/1"},{"type":"function","title":"Examples - Hologram.Template.Tokenizer.tokenize/1","doc":"iex> tokenize(\" aaa bbb \")\n    [\n      symbol: \"<\",\n      string: \"span\",\n      symbol: \">\",\n      string: \"aaa\",\n      whitespace: \" \",\n      string: \"bbb\",\n      symbol: \"</\",\n      string: \"span\",\n      symbol: \">\"\n    ]","ref":"Hologram.Template.Tokenizer.html#tokenize/1-examples"},{"type":"module","title":"Hologram.UI.Link","doc":"","ref":"Hologram.UI.Link.html"},{"type":"function","title":"Hologram.UI.Link.__is_hologram_component__/0","doc":"Returns true to indicate that the callee module is a component module (has \"use Hologram.Component\" directive).","ref":"Hologram.UI.Link.html#__is_hologram_component__/0"},{"type":"function","title":"Examples - Hologram.UI.Link.__is_hologram_component__/0","doc":"iex> __is_hologram_component__()\n    true","ref":"Hologram.UI.Link.html#__is_hologram_component__/0-examples"},{"type":"function","title":"Hologram.UI.Link.__props__/0","doc":"Returns the list of property definitions for the compiled component.","ref":"Hologram.UI.Link.html#__props__/0"},{"type":"module","title":"Hologram.UI.Runtime","doc":"","ref":"Hologram.UI.Runtime.html"},{"type":"function","title":"Hologram.UI.Runtime.__is_hologram_component__/0","doc":"Returns true to indicate that the callee module is a component module (has \"use Hologram.Component\" directive).","ref":"Hologram.UI.Runtime.html#__is_hologram_component__/0"},{"type":"function","title":"Examples - Hologram.UI.Runtime.__is_hologram_component__/0","doc":"iex> __is_hologram_component__()\n    true","ref":"Hologram.UI.Runtime.html#__is_hologram_component__/0-examples"},{"type":"function","title":"Hologram.UI.Runtime.__props__/0","doc":"Returns the list of property definitions for the compiled component.","ref":"Hologram.UI.Runtime.html#__props__/0"},{"type":"task","title":"mix compile.hologram","doc":"Builds Hologram project JavaScript bundles, the call graph of the code,\nPLTs needed by the runtime and PLTs needed to speed up future compilation.","ref":"Mix.Tasks.Compile.Hologram.html"},{"type":"function","title":"Mix.Tasks.Compile.Hologram.run/1","doc":"Benchmarks: https://github.com/bartblast/hologram/blob/master/benchmarks/mix/tasks/compile.hologram/README.md","ref":"Mix.Tasks.Compile.Hologram.html#run/1"},{"type":"task","title":"mix holo.compiler.ex_runtime_mfas","doc":"Prints the list of automatically transpiled Elixir MFAs used by the Hologram client runtime\n(manually ported Elixir MFAs are excluded).","ref":"Mix.Tasks.Holo.Compiler.ExRuntimeMfas.html"},{"type":"task","title":"mix holo.compiler.page_ex_fun_sizes","doc":"Calculates the JavaScript size of each Elixir function that is included in the specified page module bundle.\nThe results are sorted by size.","ref":"Mix.Tasks.Holo.Compiler.PageExFunSizes.html"},{"type":"task","title":"Examples - mix holo.compiler.page_ex_fun_sizes","doc":"$ mix holo.compiler.page_ex_fun_sizes MyPageModule \n\nWhere `MyPageModule` is the name of the page module you want to analyze (without the `Elixir.` prefix).","ref":"Mix.Tasks.Holo.Compiler.PageExFunSizes.html#module-examples"},{"type":"task","title":"mix holo.compiler.page_to_mfa_paths","doc":"Prints paths from page entry MFAs to the given destination MFA.","ref":"Mix.Tasks.Holo.Compiler.PageToMfaPaths.html"},{"type":"task","title":"mix holo.compiler.runtime_to_mfa_paths","doc":"Prints paths from runtime entry MFAs to the given destination MFA.","ref":"Mix.Tasks.Holo.Compiler.RuntimeToMfaPaths.html"},{"type":"task","title":"mix holo.routes","doc":"Prints the list of page routes, ordered by route path.","ref":"Mix.Tasks.Holo.Routes.html"},{"type":"task","title":"mix holo.test.check_file_names","doc":"Checks if any test scripts have invalid file names.\nFile name is valid if it ends with \"_test\" suffix and has \".exs\" extension.\nIf there are any invalid file names, the task exits with code 1.\nSupport dir and text_helper.exs file are ignored.\n\nScripts not adhering to the aforementioned rules wouldn't be picked up by the mix test task.","ref":"Mix.Tasks.Holo.Test.CheckFileNames.html"},{"type":"task","title":"Examples - mix holo.test.check_file_names","doc":"$ mix holo.test.check_file_names test/elixir","ref":"Mix.Tasks.Holo.Test.CheckFileNames.html#module-examples"},{"type":"module","title":"PriorityQueue","doc":"This module defines a priority queue datastructure, intended for use with graphs, as it prioritizes\nlower priority values over higher priority values (ideal for priorities based on edge weights, etc.).\n\nThis implementation makes use of `:gb_trees` under the covers. It is also very fast, even for a very large\nnumber of distinct priorities. Other priority queue implementations I've looked at are either slow when working\nwith large numbers of priorities, or restrict themselves to a specific number of allowed priorities, which is\nwhy I've ended up writing my own.","ref":"PriorityQueue.html"},{"type":"function","title":"PriorityQueue.new/0","doc":"Create a new priority queue","ref":"PriorityQueue.html#new/0"},{"type":"function","title":"PriorityQueue.peek/1","doc":"This function returns the value at the top of the queue. If the queue is empty, `:empty`\nis returned, otherwise `{:value, term}`. This function does not modify the queue.","ref":"PriorityQueue.html#peek/1"},{"type":"function","title":"Example - PriorityQueue.peek/1","doc":"iex> pq = PriorityQueue.new |> PriorityQueue.push(:foo, 1)\n    ...> {:value, :foo} = PriorityQueue.peek(pq)\n    ...> {{:value, val}, _} = PriorityQueue.pop(pq)\n    ...> val\n    :foo","ref":"PriorityQueue.html#peek/1-example"},{"type":"function","title":"PriorityQueue.pop/1","doc":"Pops an element from the queue with the lowest integer value priority.\n\nReturns `{:empty, PriorityQueue.t}` if there are no elements left to dequeue.\n\nReturns `{{:value, term}, PriorityQueue.t}` if the dequeue is successful\n\nThis is equivalent to the `extract-min` operation described in priority queue theory.","ref":"PriorityQueue.html#pop/1"},{"type":"function","title":"Example - PriorityQueue.pop/1","doc":"iex> pq = PriorityQueue.new\n    ...> pq = Enum.reduce(Enum.shuffle(0..4), pq, fn i, pq -> PriorityQueue.push(pq, ?a+i, i) end)\n    ...> {{:value, ?a}, pq} = PriorityQueue.pop(pq)\n    ...> {{:value, ?b}, pq} = PriorityQueue.pop(pq)\n    ...> {{:value, ?c}, pq} = PriorityQueue.pop(pq)\n    ...> {{:value, ?d}, pq} = PriorityQueue.pop(pq)\n    ...> {{:value, ?e}, pq} = PriorityQueue.pop(pq)\n    ...> {result, _} = PriorityQueue.pop(pq)\n    ...> result\n    :empty","ref":"PriorityQueue.html#pop/1-example"},{"type":"function","title":"PriorityQueue.push/3","doc":"Push a new element into the queue with the given priority.\n\nPriorities must be integer or float values.","ref":"PriorityQueue.html#push/3"},{"type":"function","title":"Example - PriorityQueue.push/3","doc":"iex> pq = PriorityQueue.new\n    ...> pq = PriorityQueue.push(pq, :foo, 1)\n    ...> {result, _} = PriorityQueue.pop(pq)\n    ...> result\n    {:value, :foo}\n\n    iex> pq = PriorityQueue.new\n    ...> pq = PriorityQueue.push(pq, :foo, 1)\n    ...> {{:value, :foo}, pq} = PriorityQueue.pop(pq)\n    ...> pq = PriorityQueue.push(pq, :bar, 1)\n    ...> {result, _} = PriorityQueue.pop(pq)\n    ...> result\n    {:value, :bar}","ref":"PriorityQueue.html#push/3-example"},{"type":"type","title":"PriorityQueue.t/0","doc":"","ref":"PriorityQueue.html#t:t/0"},{"type":"exception","title":"Graph.EdgeSpecificationError","doc":"This exception is raised when a Graph function expects one or more valid edge specifications,\nbut receives a term which does not match one of the allowed specification patterns.","ref":"Graph.EdgeSpecificationError.html"},{"type":"exception","title":"Hologram.AssetNotFoundError","doc":"Raised when an asset can't be found.","ref":"Hologram.AssetNotFoundError.html"},{"type":"exception","title":"Hologram.CompileError","doc":"Raised when a page or a component can't be compiled.","ref":"Hologram.CompileError.html"},{"type":"exception","title":"Hologram.ParamError","doc":"Raised when a page param is invalid.","ref":"Hologram.ParamError.html"},{"type":"exception","title":"Hologram.TemplateSyntaxError","doc":"Raised when template markup is invalid.","ref":"Hologram.TemplateSyntaxError.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}